@@ -117,10 +117,11 @@ void ClientObserverAdaptor::ObserveChannels(const QDBusObjectPath &accountPath,
         ", connection:" << connectionPath.path();
 
     AccountPtr account = Account::create(mBus,
-            TELEPATHY_ACCOUNT_MANAGER_BUS_NAME,
+            QLatin1String(TELEPATHY_ACCOUNT_MANAGER_BUS_NAME),
             accountPath.path());
 
-    QString connectionBusName = connectionPath.path().mid(1).replace('/', '.');
+    QString connectionBusName = connectionPath.path().mid(1).replace(
+            QLatin1String("/"), QLatin1String("."));
     ConnectionPtr connection = Connection::create(mBus, connectionBusName,
             connectionPath.path());
 
@@ -171,9 +172,11 @@ void ClientApproverAdaptor::AddDispatchOperation(const Tp::ChannelDetailsList &c
         const QDBusMessage &message)
 {
     QDBusObjectPath connectionPath = qdbus_cast<QDBusObjectPath>(
-            properties.value(TELEPATHY_INTERFACE_CHANNEL_DISPATCH_OPERATION ".Connection"));
+            properties.value(
+                QLatin1String(TELEPATHY_INTERFACE_CHANNEL_DISPATCH_OPERATION ".Connection")));
     debug() << "addDispatchOperation: connection:" << connectionPath.path();
-    QString connectionBusName = connectionPath.path().mid(1).replace('/', '.');
+    QString connectionBusName = connectionPath.path().mid(1).replace(
+            QLatin1String("/"), QLatin1String("."));
     ConnectionPtr connection = Connection::create(mBus, connectionBusName,
             connectionPath.path());
 
@@ -234,10 +237,11 @@ void ClientHandlerAdaptor::HandleChannels(const QDBusObjectPath &accountPath,
         ", connection:" << connectionPath.path();
 
     AccountPtr account = Account::create(mBus,
-            TELEPATHY_ACCOUNT_MANAGER_BUS_NAME,
+            QLatin1String(TELEPATHY_ACCOUNT_MANAGER_BUS_NAME),
             accountPath.path());
 
-    QString connectionBusName = connectionPath.path().mid(1).replace('/', '.');
+    QString connectionBusName = connectionPath.path().mid(1).replace(
+            QLatin1String("/"), QLatin1String("."));
     ConnectionPtr connection = Connection::create(mBus, connectionBusName,
             connectionPath.path());
 
@@ -348,11 +352,10 @@ struct TELEPATHY_QT4_NO_EXPORT ClientRegistrar::Private
 
 /**
  * \class ClientRegistrar
- * \ingroup clientclient
- * \headerfile <TelepathyQt4/client-registrar.h> <TelepathyQt4/ClientRegistrar>
+ * \ingroup serverclient
+ * \headerfile TelepathyQt4/client-registrar.h <TelepathyQt4/ClientRegistrar>
  *
- * Object responsible for registering
- * <a href="http://telepathy.freedesktop.org">Telepathy</a>
+ * \brief The ClientRegistrar class is responsible for registering Telepathy
  * clients (Observer, Approver, Handler).
  *
  * Clients should inherit AbstractClientObserver, AbstractClientApprover,
@@ -361,9 +364,9 @@ struct TELEPATHY_QT4_NO_EXPORT ClientRegistrar::Private
  *
  * See the individual classes descriptions for more details.
  *
- * \section usage_sec Usage
+ * \section cr_usage_sec Usage
  *
- * \subsection create_sec Creating a client registrar object
+ * \subsection cr_create_sec Creating a client registrar object
  *
  * One way to create a ClientRegistrar object is to just call the create method.
  * For example:
@@ -374,7 +377,7 @@ struct TELEPATHY_QT4_NO_EXPORT ClientRegistrar::Private
  *
  * \code ClientRegistrarPtr cr = ClientRegistrar::create(QDBusConnection::systemBus()); \endcode
  *
- * \subsection registering_sec Registering a client
+ * \subsection cr_registering_sec Registering a client
  *
  * To register a client, just call registerClient with a given AbstractClientPtr
  * pointing to a valid AbstractClient instance.
@@ -422,7 +425,7 @@ ClientRegistrarPtr ClientRegistrar::create(const QDBusConnection &bus)
 }
 
 /**
- * Construct a new client registrar object  using the given \a bus.
+ * Construct a new client registrar object using the given \a bus.
  *
  * \param bus QDBusConnection to use.
  */
@@ -455,7 +458,8 @@ QDBusConnection ClientRegistrar::dbusConnection() const
 }
 
 /**
- * Return a list of clients registered using registerClient on this client registrar.
+ * Return a list of clients registered using registerClient() on this client
+ * registrar.
  *
  * \return A list of registered clients.
  * \sa registerClient()
@@ -508,10 +512,10 @@ bool ClientRegistrar::registerClient(const AbstractClientPtr &client,
     if (unique) {
         // o.f.T.Client.<unique_bus_name>_<pointer> should be enough to identify
         // an unique identifier
-        busName.append(QString(".%1.x%2")
+        busName.append(QString(QLatin1String(".%1.x%2"))
                 .arg(mPriv->bus.baseService()
-                    .replace(':', '_')
-                    .replace('.', "._"))
+                    .replace(QLatin1String(":"), QLatin1String("_"))
+                    .replace(QLatin1String("."), QLatin1String("._")))
                 .arg((intptr_t) client.data(), 0, 16));
     }
 
@@ -569,8 +573,8 @@ bool ClientRegistrar::registerClient(const AbstractClientPtr &client,
     // export o.f.T.Client interface
     new ClientAdaptor(interfaces, object);
 
-    QString objectPath = QString("/%1").arg(busName);
-    objectPath.replace('.', '/');
+    QString objectPath = QString(QLatin1String("/%1")).arg(busName);
+    objectPath.replace(QLatin1String("."), QLatin1String("/"));
     if (!mPriv->bus.registerObject(objectPath, object)) {
         // this shouldn't happen, but let's make sure
         warning() << "Unable to register client: objectPath" <<
@@ -592,7 +596,8 @@ bool ClientRegistrar::registerClient(const AbstractClientPtr &client,
 }
 
 /**
- * Unregister a client registered using registerClient on this client registrar.
+ * Unregister a client registered using registerClient() on this client
+ * registrar.
  *
  * If \a client was not registered previously, \c false will be returned.
  *
@@ -616,7 +621,8 @@ bool ClientRegistrar::unregisterClient(const AbstractClientPtr &client)
     delete object;
     mPriv->clientObjects.remove(client);
 
-    QString busName = objectPath.mid(1).replace('/', '.');
+    QString busName = objectPath.mid(1).replace(QLatin1String("/"),
+            QLatin1String("."));
     mPriv->bus.unregisterService(busName);
     mPriv->services.remove(busName);
 
@@ -627,7 +633,8 @@ bool ClientRegistrar::unregisterClient(const AbstractClientPtr &client)
 }
 
 /**
- * Unregister all clients registered using registerClient on this client registrar.
+ * Unregister all clients registered using registerClient() on this client
+ * registrar.
  *
  * \sa registeredClients(), registerClient(), unregisterClient()
  */
