@@ -40,31 +40,15 @@
 
 #include "TelepathyQt4/debug-internal.h"
 
-/**
- * \addtogroup clientsideproxies Client-side proxies
- *
- * Proxy objects representing remote service objects accessed via D-Bus.
- *
- * In addition to providing direct access to methods, signals and properties
- * exported by the remote objects, some of these proxies offer features like
- * automatic inspection of remote object capabilities, property tracking,
- * backwards compatibility helpers for older services and other utilities.
- */
-
-/**
- * \defgroup clientconn Connection proxies
- * \ingroup clientsideproxies
- *
- * Proxy objects representing remote Telepathy Connection objects.
- */
-
 namespace Tp
 {
 
 /**
  * \class ContactManager
  * \ingroup clientconn
- * \headerfile <TelepathyQt4/contact-manager.h> <TelepathyQt4/ContactManager>
+ * \headerfile TelepathyQt4/contact-manager.h <TelepathyQt4/ContactManager>
+ *
+ * \brief The ContactManager class is responsible for managing contacts.
  */
 
 struct TELEPATHY_QT4_NO_EXPORT ContactManager::Private
@@ -107,6 +91,7 @@ struct TELEPATHY_QT4_NO_EXPORT ContactManager::Private
     ContactManager *parent;
     WeakPtr<Connection> connection;
     QMap<uint, QWeakPointer<Contact> > contacts;
+    Contacts cachedAllKnownContacts;
 
     QMap<Contact::Feature, bool> tracking;
     void ensureTracking(Contact::Feature feature);
@@ -122,6 +107,10 @@ struct TELEPATHY_QT4_NO_EXPORT ContactManager::Private
 
     Contacts allKnownContacts() const;
     void updateContactsPresenceState();
+    void computeKnownContactsChanges(const Contacts &added,
+        const Contacts &pendingAdded,
+        const Contacts &remotePendingAdded,
+        const Contacts &removed);
 };
 
 ConnectionPtr ContactManager::connection() const
@@ -135,13 +124,17 @@ QString featureToInterface(Contact::Feature feature)
 {
     switch (feature) {
         case Contact::FeatureAlias:
-            return TELEPATHY_INTERFACE_CONNECTION_INTERFACE_ALIASING;
+            return QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_ALIASING);
         case Contact::FeatureAvatarToken:
-            return TELEPATHY_INTERFACE_CONNECTION_INTERFACE_AVATARS;
+            return QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_AVATARS);
         case Contact::FeatureSimplePresence:
-            return TELEPATHY_INTERFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE;
+            return QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE);
         case Contact::FeatureCapabilities:
-            return TELEPATHY_INTERFACE_CONNECTION_INTERFACE_CONTACT_CAPABILITIES;
+            return QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_CONTACT_CAPABILITIES);
+        case Contact::FeatureLocation:
+            return QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_LOCATION);
+        case Contact::FeatureInfo:
+            return QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_CONTACT_INFO);
         default:
             warning() << "ContactManager doesn't know which interface corresponds to feature"
                 << feature;
@@ -152,14 +145,15 @@ QString featureToInterface(Contact::Feature feature)
 
 QSet<Contact::Feature> ContactManager::supportedFeatures() const
 {
-
     if (mPriv->supportedFeatures.isEmpty() &&
-        connection()->interfaces().contains(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_CONTACTS)) {
+        connection()->interfaces().contains(QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_CONTACTS))) {
         QList<Contact::Feature> allFeatures = QList<Contact::Feature>()
             << Contact::FeatureAlias
             << Contact::FeatureAvatarToken
             << Contact::FeatureSimplePresence
-            << Contact::FeatureCapabilities;
+            << Contact::FeatureCapabilities
+            << Contact::FeatureLocation
+            << Contact::FeatureInfo;
         QStringList interfaces = connection()->contactAttributeInterfaces();
         foreach (Contact::Feature feature, allFeatures) {
             if (interfaces.contains(featureToInterface(feature))) {
@@ -227,7 +221,7 @@ PendingOperation *ContactManager::addGroup(const QString &group)
 {
     QVariantMap request;
     request.insert(QLatin1String(TELEPATHY_INTERFACE_CHANNEL ".ChannelType"),
-                                  TELEPATHY_INTERFACE_CHANNEL_TYPE_CONTACT_LIST);
+                                 QLatin1String(TELEPATHY_INTERFACE_CHANNEL_TYPE_CONTACT_LIST));
     request.insert(QLatin1String(TELEPATHY_INTERFACE_CHANNEL ".TargetHandleType"),
                                  (uint) Tp::HandleTypeGroup);
     request.insert(QLatin1String(TELEPATHY_INTERFACE_CHANNEL ".TargetID"),
@@ -248,8 +242,8 @@ PendingOperation *ContactManager::addGroup(const QString &group)
 PendingOperation *ContactManager::removeGroup(const QString &group)
 {
     if (!mPriv->contactListGroupChannels.contains(group)) {
-        return new PendingFailure(TELEPATHY_ERROR_INVALID_ARGUMENT,
-                "Invalid group", this);
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_INVALID_ARGUMENT),
+                QLatin1String("Invalid group"), this);
     }
 
     ChannelPtr channel = mPriv->contactListGroupChannels[group];
@@ -294,8 +288,8 @@ PendingOperation *ContactManager::addContactsToGroup(const QString &group,
         const QList<ContactPtr> &contacts)
 {
     if (!mPriv->contactListGroupChannels.contains(group)) {
-        return new PendingFailure(TELEPATHY_ERROR_INVALID_ARGUMENT,
-                "Invalid group", this);
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_INVALID_ARGUMENT),
+                QLatin1String("Invalid group"), this);
     }
 
     ChannelPtr channel = mPriv->contactListGroupChannels[group];
@@ -317,8 +311,8 @@ PendingOperation *ContactManager::removeContactsFromGroup(const QString &group,
         const QList<ContactPtr> &contacts)
 {
     if (!mPriv->contactListGroupChannels.contains(group)) {
-        return new PendingFailure(TELEPATHY_ERROR_INVALID_ARGUMENT,
-                "Invalid group", this);
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_INVALID_ARGUMENT),
+                QLatin1String("Invalid group"), this);
     }
 
     ChannelPtr channel = mPriv->contactListGroupChannels[group];
@@ -388,8 +382,8 @@ PendingOperation *ContactManager::requestPresenceSubscription(
         const QList<ContactPtr> &contacts, const QString &message)
 {
     if (!mPriv->subscribeChannel) {
-        return new PendingFailure(TELEPATHY_ERROR_NOT_IMPLEMENTED,
-                "Cannot subscribe to contacts' presence on this protocol",
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_NOT_IMPLEMENTED),
+                QLatin1String("Cannot subscribe to contacts' presence on this protocol"),
                 this);
     }
 
@@ -476,8 +470,8 @@ PendingOperation *ContactManager::removePresenceSubscription(
         const QList<ContactPtr> &contacts, const QString &message)
 {
     if (!mPriv->subscribeChannel) {
-        return new PendingFailure(TELEPATHY_ERROR_NOT_IMPLEMENTED,
-                "Cannot subscribe to contacts' presence on this protocol",
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_NOT_IMPLEMENTED),
+                QLatin1String("Cannot subscribe to contacts' presence on this protocol"),
                 this);
     }
 
@@ -534,8 +528,8 @@ PendingOperation *ContactManager::authorizePresencePublication(
         const QList<ContactPtr> &contacts, const QString &message)
 {
     if (!mPriv->publishChannel) {
-        return new PendingFailure(TELEPATHY_ERROR_NOT_IMPLEMENTED,
-                "Cannot control publication of presence on this protocol",
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_NOT_IMPLEMENTED),
+                QLatin1String("Cannot control publication of presence on this protocol"),
                 this);
     }
 
@@ -617,8 +611,8 @@ PendingOperation *ContactManager::removePresencePublication(
         const QList<ContactPtr> &contacts, const QString &message)
 {
     if (!mPriv->publishChannel) {
-        return new PendingFailure(TELEPATHY_ERROR_NOT_IMPLEMENTED,
-                "Cannot control publication of presence on this protocol",
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_NOT_IMPLEMENTED),
+                QLatin1String("Cannot control publication of presence on this protocol"),
                 this);
     }
 
@@ -651,8 +645,8 @@ PendingOperation *ContactManager::blockContacts(
         const QList<ContactPtr> &contacts, bool value)
 {
     if (!mPriv->denyChannel) {
-        return new PendingFailure(TELEPATHY_ERROR_NOT_IMPLEMENTED,
-                "Cannot block contacts on this protocol",
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_NOT_IMPLEMENTED),
+                QLatin1String("Cannot block contacts on this protocol"),
                 this);
     }
 
@@ -787,6 +781,29 @@ void ContactManager::onCapabilitiesChanged(const ContactCapabilitiesMap &caps)
     }
 }
 
+void ContactManager::onLocationUpdated(uint handle, const QVariantMap &location)
+{
+    debug() << "Got LocationUpdated for contact with handle" << handle;
+
+    ContactPtr contact = lookupContactByHandle(handle);
+
+    if (contact) {
+        contact->receiveLocation(location);
+    }
+}
+
+void ContactManager::onContactInfoChanged(uint handle,
+        const Tp::ContactInfoFieldList &info)
+{
+    debug() << "Got ContactInfoChanged for contact with handle" << handle;
+
+    ContactPtr contact = lookupContactByHandle(handle);
+
+    if (contact) {
+        contact->receiveInfo(info);
+    }
+}
+
 void ContactManager::onSubscribeChannelMembersChanged(
         const Contacts &groupMembersAdded,
         const Contacts &groupLocalPendingMembersAdded,
@@ -814,6 +831,12 @@ void ContactManager::onSubscribeChannelMembersChanged(
         debug() << "Contact" << contact->id() << "removed from subscribe list";
         contact->setSubscriptionState(Contact::PresenceStateNo);
     }
+
+    // Perform the needed computation for allKnownContactsChanged
+    mPriv->computeKnownContactsChanges(groupMembersAdded,
+                                       groupLocalPendingMembersAdded,
+                                       groupRemotePendingMembersAdded,
+                                       groupMembersRemoved);
 }
 
 void ContactManager::onPublishChannelMembersChanged(
@@ -847,6 +870,12 @@ void ContactManager::onPublishChannelMembersChanged(
     if (!groupLocalPendingMembersAdded.isEmpty()) {
         emit presencePublicationRequested(groupLocalPendingMembersAdded);
     }
+
+    // Perform the needed computation for allKnownContactsChanged
+    mPriv->computeKnownContactsChanges(groupMembersAdded,
+                                       groupLocalPendingMembersAdded,
+                                       groupRemotePendingMembersAdded,
+                                       groupMembersRemoved);
 }
 
 void ContactManager::onDenyChannelMembersChanged(
@@ -966,6 +995,8 @@ void ContactManager::setContactListChannels(
     }
 
     mPriv->updateContactsPresenceState();
+    // Refresh the cache for the current known contacts
+    mPriv->cachedAllKnownContacts = allKnownContacts();
 
     QMap<uint, ContactListChannel>::const_iterator i = contactListChannels.constBegin();
     QMap<uint, ContactListChannel>::const_iterator end = contactListChannels.constEnd();
@@ -1088,6 +1119,22 @@ void ContactManager::Private::ensureTracking(Contact::Feature feature)
                     SLOT(onCapabilitiesChanged(const Tp::ContactCapabilitiesMap &)));
             break;
 
+        case Contact::FeatureLocation:
+            QObject::connect(
+                    conn->locationInterface(),
+                    SIGNAL(LocationUpdated(uint, const QVariantMap &)),
+                    conn->contactManager(),
+                    SLOT(onLocationUpdated(uint, const QVariantMap &)));
+            break;
+
+        case Contact::FeatureInfo:
+            QObject::connect(
+                    conn->contactInfoInterface(),
+                    SIGNAL(ContactInfoChanged(uint, const Tp::ContactInfoFieldList &)),
+                    conn->contactManager(),
+                    SLOT(onContactInfoChanged(uint, const Tp::ContactInfoFieldList &)));
+            break;
+
         default:
             warning() << " Unknown feature" << feature
                 << "when trying to figure out how to connect change notification!";
@@ -1112,6 +1159,40 @@ Contacts ContactManager::Private::allKnownContacts() const
     return contacts;
 }
 
+void ContactManager::Private::computeKnownContactsChanges(const Tp::Contacts& added,
+                                                          const Tp::Contacts& pendingAdded,
+                                                          const Tp::Contacts& remotePendingAdded,
+                                                          const Tp::Contacts& removed)
+{
+    // First of all, compute the real additions/removals based upon our cache
+    Tp::Contacts realAdded;
+    realAdded.unite(added);
+    realAdded.unite(pendingAdded);
+    realAdded.unite(remotePendingAdded);
+    realAdded.subtract(cachedAllKnownContacts);
+    Tp::Contacts realRemoved = removed;
+    realRemoved.intersect(cachedAllKnownContacts);
+
+    // Check if realRemoved have been _really_ removed from all lists
+    foreach (const ContactListChannel &contactListChannel, contactListChannels) {
+        ChannelPtr channel = contactListChannel.channel;
+        if (!channel) {
+            continue;
+        }
+        realRemoved.subtract(channel->groupContacts());
+        realRemoved.subtract(channel->groupLocalPendingContacts());
+        realRemoved.subtract(channel->groupRemotePendingContacts());
+    }
+
+    // Are there any real changes?
+    if (!realAdded.isEmpty() || !realRemoved.isEmpty()) {
+        // Yes, update our "cache" and emit the signal
+        cachedAllKnownContacts.unite(realAdded);
+        cachedAllKnownContacts.subtract(realRemoved);
+        emit parent->allKnownContactsChanged(realAdded, realRemoved);
+    }
+}
+
 void ContactManager::Private::updateContactsPresenceState()
 {
     Contacts subscribeContacts;
