@@ -37,7 +37,9 @@ namespace Tp
 {
 
 class ContactCapabilities;
+class ContactLocation;
 class ContactManager;
+class PendingContactInfo;
 class PendingOperation;
 class ReferencedHandles;
 
@@ -52,6 +54,8 @@ public:
         FeatureAvatarToken,
         FeatureSimplePresence,
         FeatureCapabilities,
+        FeatureLocation,
+        FeatureInfo,
         _Padding = 0xFFFFFFFF
     };
 
@@ -80,6 +84,12 @@ public:
 
     ContactCapabilities *capabilities() const;
 
+    ContactLocation *location() const;
+
+    ContactInfoFieldList info() const;
+    PendingOperation *refreshInfo();
+    PendingContactInfo *requestInfo();
+
     PresenceState subscriptionState() const;
     PresenceState publishState() const;
 
@@ -102,6 +112,8 @@ Q_SIGNALS:
     void avatarTokenChanged(const QString &avatarToken);
     void simplePresenceChanged(const QString &status, uint type, const QString &presenceMessage);
     void capabilitiesChanged(Tp::ContactCapabilities *caps);
+    void locationUpdated(Tp::ContactLocation *location);
+    void infoChanged(const Tp::ContactInfoFieldList &info);
 
     void subscriptionStateChanged(Tp::Contact::PresenceState state);
     void publishStateChanged(Tp::Contact::PresenceState state);
@@ -126,6 +138,8 @@ private:
     void receiveAvatarToken(const QString &avatarToken);
     void receiveSimplePresence(const SimplePresence &presence);
     void receiveCapabilities(const RequestableChannelClassList &caps);
+    void receiveLocation(const QVariantMap &location);
+    void receiveInfo(const ContactInfoFieldList &info);
 
     void setSubscriptionState(PresenceState state);
     void setPublishState(PresenceState state);
