@@ -122,7 +122,7 @@ void FileTransferChannel::Private::introspectProperties(
     QDBusPendingCallWatcher *watcher =
         new QDBusPendingCallWatcher(
                 self->properties->GetAll(
-                    TELEPATHY_INTERFACE_CHANNEL_TYPE_FILE_TRANSFER),
+                    QLatin1String(TELEPATHY_INTERFACE_CHANNEL_TYPE_FILE_TRANSFER)),
                 self->parent);
     self->parent->connect(watcher,
             SIGNAL(finished(QDBusPendingCallWatcher *)),
@@ -131,38 +131,54 @@ void FileTransferChannel::Private::introspectProperties(
 
 void FileTransferChannel::Private::extractProperties(const QVariantMap &props)
 {
-    pendingState = state = qdbus_cast<uint>(props["State"]);
-    contentType = qdbus_cast<QString>(props["ContentType"]);
-    fileName = qdbus_cast<QString>(props["Filename"]);
-    contentHash = qdbus_cast<QString>(props["ContentHash"]);
-    description = qdbus_cast<QString>(props["Description"]);
-    lastModificationTime.setTime_t((uint) qdbus_cast<qulonglong>(props["Date"]));
-    contentHashType = (FileHashType) qdbus_cast<uint>(props["ContentHashType"]);
-    initialOffset = qdbus_cast<qulonglong>(props["InitialOffset"]);
-    size = qdbus_cast<qulonglong>(props["Size"]);
-    transferredBytes = qdbus_cast<qulonglong>(props["TransferredBytes"]);
-    availableSocketTypes = qdbus_cast<SupportedSocketMap>(props["AvailableSocketTypes"]);
+    pendingState = state = qdbus_cast<uint>(props[QLatin1String("State")]);
+    contentType = qdbus_cast<QString>(props[QLatin1String("ContentType")]);
+    fileName = qdbus_cast<QString>(props[QLatin1String("Filename")]);
+    contentHash = qdbus_cast<QString>(props[QLatin1String("ContentHash")]);
+    description = qdbus_cast<QString>(props[QLatin1String("Description")]);
+    lastModificationTime.setTime_t((uint) qdbus_cast<qulonglong>(props[QLatin1String("Date")]));
+    contentHashType = (FileHashType) qdbus_cast<uint>(props[QLatin1String("ContentHashType")]);
+    initialOffset = qdbus_cast<qulonglong>(props[QLatin1String("InitialOffset")]);
+    size = qdbus_cast<qulonglong>(props[QLatin1String("Size")]);
+    transferredBytes = qdbus_cast<qulonglong>(props[QLatin1String("TransferredBytes")]);
+    availableSocketTypes = qdbus_cast<SupportedSocketMap>(props[QLatin1String("AvailableSocketTypes")]);
 }
 
 /**
  * \class FileTransferChannel
  * \ingroup clientchannel
- * \headerfile <TelepathyQt4/file-transfer-channel.h> <TelepathyQt4/FileTransferChannel>
+ * \headerfile TelepathyQt4/file-transfer-channel.h <TelepathyQt4/FileTransferChannel>
  *
- * \brief The FileTransferChannel class provides an object representing
- * <a href="http://telepathy.freedesktop.org">Telepathy</a> file transfer
- * channel.
+ * \brief The FileTransferChannel class provides an object representing a
+ * Telepathy channel of type FileTransfer.
  *
- * FileTransferChannel is a high-level class representing a
- * <a href="http://telepathy.freedesktop.org">Telepathy</a> file transfer
- * channel.
-
  * For more specialized file transfer classes, please refer to
  * OutgoingFileTransferChannel and IncomingFileTransferChannel.
  */
 
-const Feature FileTransferChannel::FeatureCore = Feature(FileTransferChannel::staticMetaObject.className(), 0);
+/**
+ * Feature representing the core that needs to become ready to make the
+ * FileTransferChannel object usable.
+ *
+ * Note that this feature must be enabled in order to use most
+ * FileTransferChannel methods.
+ * See specific methods documentation for more details.
+ *
+ * When calling isReady(), becomeReady(), this feature is implicitly added
+ * to the requested features.
+ */
+const Feature FileTransferChannel::FeatureCore = Feature(QLatin1String(FileTransferChannel::staticMetaObject.className()), 0);
 
+/**
+ * Create a new FileTransferChannel object.
+ *
+ * \param connection Connection owning this channel, and specifying the
+ *                   service.
+ * \param objectPath The object path of this channel.
+ * \param immutableProperties The immutable properties of this channel.
+ * \return A StreamedMediaChannelPtr object pointing to the newly created
+ *         StreamedMediaChannel object.
+ */
 FileTransferChannelPtr FileTransferChannel::create(const ConnectionPtr &connection,
         const QString &objectPath, const QVariantMap &immutableProperties)
 {
