@@ -32,17 +32,6 @@
 #include <TelepathyQt4/PendingFailure>
 #include <TelepathyQt4/PendingReady>
 
-/**
- * \addtogroup clientsideproxies Client-side proxies
- *
- * Proxy objects representing remote service objects accessed via D-Bus.
- *
- * In addition to providing direct access to methods, signals and properties
- * exported by the remote objects, some of these proxies offer features like
- * automatic inspection of remote object capabilities, property tracking,
- * backwards compatibility helpers for older services and other utilities.
- */
-
 namespace Tp
 {
 
@@ -61,10 +50,10 @@ struct TELEPATHY_QT4_NO_EXPORT PendingChannelRequest::Private
 
 /**
  * \class PendingChannelRequest
- * \ingroup clientconn
- * \headerfile <TelepathyQt4/pending-channel-request.h> <TelepathyQt4/PendingChannelRequest>
+ * \ingroup clientchannelrequest
+ * \headerfile TelepathyQt4/pending-channel-request.h <TelepathyQt4/PendingChannelRequest>
  *
- * Class containing the parameters of and the reply to an asynchronous
+ * \brief Class containing the parameters of and the reply to an asynchronous
  * ChannelRequest request. Instances of this class cannot be constructed
  * directly; the only way to get one is trough Account.
  */
@@ -96,11 +85,11 @@ PendingChannelRequest::PendingChannelRequest(const QDBusConnection &dbusConnecti
       mPriv(new Private(dbusConnection))
 {
     QString channelDispatcherObjectPath =
-        QString("/%1").arg(TELEPATHY_INTERFACE_CHANNEL_DISPATCHER);
-    channelDispatcherObjectPath.replace('.', '/');
+        QString(QLatin1String("/%1")).arg(QLatin1String(TELEPATHY_INTERFACE_CHANNEL_DISPATCHER));
+    channelDispatcherObjectPath.replace(QLatin1String("."), QLatin1String("/"));
     Client::ChannelDispatcherInterface *channelDispatcherInterface =
         new Client::ChannelDispatcherInterface(mPriv->dbusConnection,
-                TELEPATHY_INTERFACE_CHANNEL_DISPATCHER,
+                QLatin1String(TELEPATHY_INTERFACE_CHANNEL_DISPATCHER),
                 channelDispatcherObjectPath,
                 this);
     QDBusPendingCallWatcher *watcher;
@@ -150,8 +139,8 @@ PendingOperation *PendingChannelRequest::cancel()
 {
     if (isFinished()) {
         // CR has already succeeded or failed, so let's just fail here
-        return new PendingFailure(TELEPATHY_DBUS_ERROR_UNKNOWN_METHOD,
-                "ChannnelRequest already finished", this);
+        return new PendingFailure(QLatin1String(TELEPATHY_DBUS_ERROR_UNKNOWN_METHOD),
+                QLatin1String("ChannnelRequest already finished"), this);
     }
 
     if (!mPriv->cancelOperation) {
@@ -182,8 +171,8 @@ void PendingChannelRequest::onWatcherFinished(QDBusPendingCallWatcher *watcher)
 
         if (mPriv->cancelOperation) {
             mPriv->cancelOperation->go(mPriv->channelRequest);
-            setFinishedWithError(TELEPATHY_ERROR_CANCELLED,
-                    "ChannelRequest cancelled");
+            setFinishedWithError(QLatin1String(TELEPATHY_ERROR_CANCELLED),
+                    QLatin1String("ChannelRequest cancelled"));
         } else {
             emit channelRequestCreated(mPriv->channelRequest);
 
