@@ -46,7 +46,7 @@ struct TELEPATHY_QT4_NO_EXPORT PendingSendMessage::Private
 };
 
 inline PendingSendMessage::Private::Private(const Message &message)
-    : token(QString::fromAscii("")), message(message)
+    : token(QLatin1String("")), message(message)
 {
 }
 
@@ -202,9 +202,9 @@ TextChannel::Private::Private(TextChannel *parent)
     introspectables[FeatureMessageSentSignal] = introspectableMessageSentSignal;
 
     ReadinessHelper::Introspectable introspectableChatState(
-        QSet<uint>() << 0,                                                      // makesSenseForStatuses
-        Features() << Channel::FeatureCore,                                     // dependsOnFeatures (core)
-        QStringList(TELEPATHY_INTERFACE_CHANNEL_INTERFACE_CHAT_STATE),          // dependsOnInterfaces
+        QSet<uint>() << 0,                                                                  // makesSenseForStatuses
+        Features() << Channel::FeatureCore,                                                 // dependsOnFeatures (core)
+        QStringList() << QLatin1String(TELEPATHY_INTERFACE_CHANNEL_INTERFACE_CHAT_STATE),   // dependsOnInterfaces
         (ReadinessHelper::IntrospectFunc) &Private::enableChatStateNotifications,
         this);
     introspectables[FeatureChatState] = introspectableChatState;
@@ -343,7 +343,7 @@ void TextChannel::Private::updateInitialMessages()
     initialMessagesReceived = true;
 
     MessagePartListList messages = qdbus_cast<MessagePartListList>(
-            props["PendingMessages"]);
+            props[QLatin1String("PendingMessages")]);
     if (messages.isEmpty()) {
         debug() << "Message queue empty: FeatureMessageQueue is now ready";
         readinessHelper->setIntrospectCompleted(FeatureMessageQueue, true);
@@ -362,14 +362,14 @@ void TextChannel::Private::updateCapabilities()
     }
 
     supportedContentTypes = qdbus_cast<QStringList>(
-            props["SupportedContentTypes"]);
+            props[QLatin1String("SupportedContentTypes")]);
     if (supportedContentTypes.isEmpty()) {
         supportedContentTypes << QLatin1String("text/plain");
     }
     messagePartSupport = MessagePartSupportFlags(qdbus_cast<uint>(
-            props["MessagePartSupportFlags"]));
+            props[QLatin1String("MessagePartSupportFlags")]));
     deliveryReportingSupport = DeliveryReportingSupportFlags(
-            qdbus_cast<uint>(props["DeliveryReportingSupport"]));
+            qdbus_cast<uint>(props[QLatin1String("DeliveryReportingSupport")]));
     readinessHelper->setIntrospectCompleted(FeatureMessageCapabilities, true);
 }
 
@@ -535,41 +535,38 @@ void TextChannel::Private::contactFound(ContactPtr contact)
 /**
  * \class TextChannel
  * \ingroup clientchannel
- * \headerfile <TelepathyQt4/text-channel.h> <TelepathyQt4/TextChannel>
+ * \headerfile TelepathyQt4/text-channel.h <TelepathyQt4/TextChannel>
  *
- * High-level proxy object for accessing remote %Channel objects of the Text
- * channel type.
- *
- * This subclass of Channel will eventually provide a high-level API for the
- * Text and Messages interface. Until then, it's just a Channel.
+ * \brief The TextChannel class provides an object representing a
+ * Telepathy channel of type Text.
  */
 
 /**
- * \var Feature TextChannel::FeatureMessageQueue
- * The messageQueue method can be called, and the messageReceived and
- * pendingMessageRemoved methods can be called
+ * Feature used in order to access the message queue info.
+ *
+ * Se message queue methods' documentation for more details.
  */
+const Feature TextChannel::FeatureMessageQueue = Feature(QLatin1String(TextChannel::staticMetaObject.className()), 0);
+
 /**
- * \var Feature TextChannel::FeatureMessageCapabilities
- * The supportedContentTypes, messagePartSupport and deliveryReportingSupport
- * methods can be called
+ * Feature used in order to access message capabilities info.
+ *
+ * Se message capabilities methods' documentation for more details.
  */
+const Feature TextChannel::FeatureMessageCapabilities = Feature(QLatin1String(TextChannel::staticMetaObject.className()), 1);
+
 /**
- * \var Feature TextChannel::FeatureMessageSentSignal
- * The messageSent signal will be emitted when a message is sent
+ * Feature used in order to receive notification when a message is sent.
  */
+const Feature TextChannel::FeatureMessageSentSignal = Feature(QLatin1String(TextChannel::staticMetaObject.className()), 2);
+
 /**
- * \var Feature TextChannel::FeatureChatState
- * Enable this feature in order to receive notifications of remote contacts'
- * state.
+ * Feature used in order to keep track of chat state changes.
+ *
  * The chatStateChanged() signal will be emitted when a remote contact chat
  * state changes.
  */
-
-const Feature TextChannel::FeatureMessageQueue = Feature(TextChannel::staticMetaObject.className(), 0);
-const Feature TextChannel::FeatureMessageCapabilities = Feature(TextChannel::staticMetaObject.className(), 1);
-const Feature TextChannel::FeatureMessageSentSignal = Feature(TextChannel::staticMetaObject.className(), 2);
-const Feature TextChannel::FeatureChatState = Feature(TextChannel::staticMetaObject.className(), 3);
+const Feature TextChannel::FeatureChatState = Feature(QLatin1String(TextChannel::staticMetaObject.className()), 3);
 
 /**
  * \fn void TextChannel::messageSent(const Tp::Message &message,
@@ -621,6 +618,16 @@ const Feature TextChannel::FeatureChatState = Feature(TextChannel::staticMetaObj
  * This includes local state.
  */
 
+/**
+ * Create a new IncomingFileTransfer channel.
+ *
+ * \param connection Connection owning this channel, and specifying the
+ *                   service.
+ * \param objectPath The object path of this channel.
+ * \param immutableProperties The immutable properties of this channel.
+ * \return A TextChannelPtr object pointing to the newly created
+ *         TextChannel object.
+ */
 TextChannelPtr TextChannel::create(const ConnectionPtr &connection,
         const QString &objectPath, const QVariantMap &immutableProperties)
 {
@@ -629,15 +636,12 @@ TextChannelPtr TextChannel::create(const ConnectionPtr &connection,
 }
 
 /**
- * Creates a TextChannel associated with the given object on the same service
- * as the given connection.
+ * Construct a new TextChannel object.
  *
- * \param connection  Connection owning this TextChannel, and specifying the
- *                    service.
- * \param objectPath  Path to the object on the service.
- * \param immutableProperties The immutable D-Bus properties of the channel
- *                    (as announced in the NewChannels D-Bus signal), used to
- *                    reduce D-Bus round trips
+ * \param connection Connection owning this channel, and specifying the
+ *                   service.
+ * \param objectPath The object path of this channel.
+ * \param immutableProperties The immutable properties of this channel.
  */
 TextChannel::TextChannel(const ConnectionPtr &connection,
         const QString &objectPath,
@@ -956,11 +960,11 @@ PendingSendMessage *TextChannel::send(const MessagePartList &parts,
  */
 PendingOperation *TextChannel::requestChatState(ChannelChatState state)
 {
-    if (!interfaces().contains(TELEPATHY_INTERFACE_CHANNEL_INTERFACE_CHAT_STATE)) {
+    if (!interfaces().contains(QLatin1String(TELEPATHY_INTERFACE_CHANNEL_INTERFACE_CHAT_STATE))) {
         warning() << "TextChannel::requestChatState() used with no chat "
             "state interface";
-        return new PendingFailure(TELEPATHY_ERROR_NOT_IMPLEMENTED,
-                "TextChannel does not support chat state interface",
+        return new PendingFailure(QLatin1String(TELEPATHY_ERROR_NOT_IMPLEMENTED),
+                QLatin1String("TextChannel does not support chat state interface"),
                 this);
     }
     return new PendingVoid(chatStateInterface()->SetChatState(
@@ -1032,7 +1036,7 @@ void TextChannel::onPendingMessagesRemoved(const UIntList &ids)
 void TextChannel::onTextSent(uint timestamp, uint type, const QString &text)
 {
     emit messageSent(Message(timestamp, type, text), 0,
-            QString::fromAscii(""));
+            QLatin1String(""));
 }
 
 void TextChannel::onTextReceived(uint id, uint timestamp, uint sender,
@@ -1047,28 +1051,28 @@ void TextChannel::onTextReceived(uint id, uint timestamp, uint sender,
     if (timestamp == 0) {
         timestamp = QDateTime::currentDateTime().toTime_t();
     }
-    header.insert(QString::fromAscii("message-received"),
+    header.insert(QLatin1String("message-received"),
             QDBusVariant(static_cast<qlonglong>(timestamp)));
 
-    header.insert(QString::fromAscii("pending-message-id"), QDBusVariant(id));
-    header.insert(QString::fromAscii("message-sender"), QDBusVariant(sender));
-    header.insert(QString::fromAscii("message-type"), QDBusVariant(type));
+    header.insert(QLatin1String("pending-message-id"), QDBusVariant(id));
+    header.insert(QLatin1String("message-sender"), QDBusVariant(sender));
+    header.insert(QLatin1String("message-type"), QDBusVariant(type));
 
     if (flags & ChannelTextMessageFlagScrollback) {
-        header.insert(QString::fromAscii("scrollback"), QDBusVariant(true));
+        header.insert(QLatin1String("scrollback"), QDBusVariant(true));
     }
     if (flags & ChannelTextMessageFlagRescued) {
-        header.insert(QString::fromAscii("rescued"), QDBusVariant(true));
+        header.insert(QLatin1String("rescued"), QDBusVariant(true));
     }
 
     MessagePart body;
 
-    body.insert(QString::fromAscii("content-type"),
-            QDBusVariant(QString::fromAscii("text/plain")));
-    body.insert(QString::fromAscii("content"), QDBusVariant(text));
+    body.insert(QLatin1String("content-type"),
+            QDBusVariant(QLatin1String("text/plain")));
+    body.insert(QLatin1String("content"), QDBusVariant(text));
 
     if (flags & ChannelTextMessageFlagTruncated) {
-        header.insert(QString::fromAscii("truncated"), QDBusVariant(true));
+        header.insert(QLatin1String("truncated"), QDBusVariant(true));
     }
 
     MessagePartList parts;
@@ -1095,10 +1099,10 @@ void TextChannel::onTextSendError(uint error, uint timestamp, uint type,
 
     MessagePart header;
 
-    header.insert(QString::fromAscii("message-received"),
+    header.insert(QLatin1String("message-received"),
             QDBusVariant(static_cast<qlonglong>(
                     QDateTime::currentDateTime().toTime_t())));
-    header.insert(QString::fromAscii("message-type"),
+    header.insert(QLatin1String("message-type"),
             QDBusVariant(static_cast<uint>(
                     ChannelTextMessageTypeDeliveryReport)));
 
@@ -1123,25 +1127,25 @@ void TextChannel::onTextSendError(uint error, uint timestamp, uint type,
             break;
     }
 
-    header.insert(QString::fromAscii("delivery-status"),
+    header.insert(QLatin1String("delivery-status"),
             QDBusVariant(deliveryStatus));
-    header.insert(QString::fromAscii("delivery-error"), QDBusVariant(error));
+    header.insert(QLatin1String("delivery-error"), QDBusVariant(error));
 
     MessagePart echoHeader;
-    echoHeader.insert(QString::fromAscii("message-sent"),
+    echoHeader.insert(QLatin1String("message-sent"),
             QDBusVariant(timestamp));
-    echoHeader.insert(QString::fromAscii("message-type"),
+    echoHeader.insert(QLatin1String("message-type"),
             QDBusVariant(type));
 
     MessagePart echoBody;
-    echoBody.insert(QString::fromAscii("content-type"),
-            QDBusVariant(QString::fromAscii("text/plain")));
-    echoBody.insert(QString::fromAscii("content"), QDBusVariant(text));
+    echoBody.insert(QLatin1String("content-type"),
+            QDBusVariant(QLatin1String("text/plain")));
+    echoBody.insert(QLatin1String("content"), QDBusVariant(text));
 
     MessagePartList echo;
     echo << echoHeader;
     echo << echoBody;
-    header.insert(QString::fromAscii("delivery-echo"),
+    header.insert(QLatin1String("delivery-echo"),
             QDBusVariant(QVariant::fromValue(echo)));
 
     MessagePartList parts;
