@@ -28,6 +28,7 @@
 
 #include <TelepathyQt4/_gen/types.h>
 
+#include <TelepathyQt4/Global>
 #include <TelepathyQt4/SharedPtr>
 #include <TelepathyQt4/MethodInvocationContext>
 
@@ -35,9 +36,11 @@
 
 namespace Tp
 {
+TELEPATHY_QT4_EXPORT void registerTypes();
 
 class AbstractClient;
 class Account;
+class AccountSet;
 class AccountManager;
 class Channel;
 class ChannelDispatchOperation;
@@ -51,12 +54,14 @@ class FileTransferChannel;
 class IncomingFileTransferChannel;
 class OutgoingFileTransferChannel;
 class RoomListChannel;
+class MediaContent;
 class MediaStream;
 class StreamedMediaChannel;
 class TextChannel;
 
 typedef SharedPtr<AbstractClient> AbstractClientPtr;
 typedef SharedPtr<Account> AccountPtr;
+typedef SharedPtr<AccountSet> AccountSetPtr;
 typedef SharedPtr<AccountManager> AccountManagerPtr;
 typedef SharedPtr<Channel> ChannelPtr;
 typedef SharedPtr<ChannelDispatchOperation> ChannelDispatchOperationPtr;
@@ -70,6 +75,7 @@ typedef SharedPtr<FileTransferChannel> FileTransferChannelPtr;
 typedef SharedPtr<IncomingFileTransferChannel> IncomingFileTransferChannelPtr;
 typedef SharedPtr<OutgoingFileTransferChannel> OutgoingFileTransferChannelPtr;
 typedef SharedPtr<RoomListChannel> RoomListChannelPtr;
+typedef SharedPtr<MediaContent> MediaContentPtr;
 typedef SharedPtr<MediaStream> MediaStreamPtr;
 typedef SharedPtr<StreamedMediaChannel> StreamedMediaChannelPtr;
 typedef SharedPtr<TextChannel> TextChannelPtr;
