@@ -1,15 +1,23 @@
-#include <tests/lib/test.h>
+#include <QtCore/QDebug>
+#include <QtCore/QTimer>
 
-#include <tests/lib/glib-helpers/test-conn-helper.h>
+#include <QtDBus/QtDBus>
+
+#include <QtTest/QtTest>
+
+#include <TelepathyQt4/Connection>
+#include <TelepathyQt4/Message>
+#include <TelepathyQt4/PendingReady>
+#include <TelepathyQt4/ReceivedMessage>
+#include <TelepathyQt4/TextChannel>
+#include <TelepathyQt4/Debug>
+
+#include <telepathy-glib/debug.h>
 
 #include <tests/lib/glib/echo/chan.h>
 #include <tests/lib/glib/echo/conn.h>
 #include <tests/lib/glib/future/conference/chan.h>
-
-#include <TelepathyQt/Connection>
-#include <TelepathyQt/PendingReady>
-
-#include <telepathy-glib/debug.h>
+#include <tests/lib/test.h>
 
 using namespace Tp;
 
@@ -20,14 +28,13 @@ class TestConferenceChan : public Test
 public:
     TestConferenceChan(QObject *parent = 0)
         : Test(parent),
-          mConn(0), mContactRepo(0),
+          mConnService(0), mBaseConnService(0), mContactRepo(0),
           mTextChan1Service(0), mTextChan2Service(0), mConferenceChanService(0)
     { }
 
 protected Q_SLOTS:
     void onConferenceChannelMerged(const Tp::ChannelPtr &);
-    void onConferenceChannelRemoved(const Tp::ChannelPtr &channel,
-            const Tp::Channel::GroupMemberChangeDetails &details);
+    // void onConferenceChannelRemoved(const Tp::ChannelPtr &);
 
 private Q_SLOTS:
     void initTestCase();
@@ -39,10 +46,15 @@ private Q_SLOTS:
     void cleanupTestCase();
 
 private:
-    TestConnHelper *mConn;
+    ExampleEchoConnection *mConnService;
+    TpBaseConnection *mBaseConnService;
     TpHandleRepoIface *mContactRepo;
 
+    QString mConnName;
+    QString mConnPath;
+    ConnectionPtr mConn;
     ChannelPtr mChan;
+
     QString mTextChan1Path;
     ExampleEchoChannel *mTextChan1Service;
     QString mTextChan2Path;
@@ -50,11 +62,9 @@ private:
     QString mTextChan3Path;
     ExampleEchoChannel *mTextChan3Service;
     QString mConferenceChanPath;
-    TpTestsConferenceChannel *mConferenceChanService;
+    ExampleConferenceChannel *mConferenceChanService;
 
     ChannelPtr mChannelMerged;
-    ChannelPtr mChannelRemovedDetailed;
-    Channel::GroupMemberChangeDetails mChannelRemovedDetailedDetails;
 };
 
 void TestConferenceChan::onConferenceChannelMerged(const Tp::ChannelPtr &channel)
@@ -63,32 +73,55 @@ void TestConferenceChan::onConferenceChannelMerged(const Tp::ChannelPtr &channel
     mLoop->exit(0);
 }
 
-void TestConferenceChan::onConferenceChannelRemoved(const Tp::ChannelPtr &channel,
-        const Tp::Channel::GroupMemberChangeDetails &details)
-{
-    mChannelRemovedDetailed = channel;
-    mChannelRemovedDetailedDetails = details;
-    mLoop->exit(0);
-}
-
 void TestConferenceChan::initTestCase()
 {
     initTestCaseImpl();
 
     g_type_init();
-    g_set_prgname("chan-conference");
+    g_set_prgname("conference-chan");
     tp_debug_set_flags("all");
     dbus_g_bus_get(DBUS_BUS_STARTER, 0);
 
-    mConn = new TestConnHelper(this,
+    gchar *name;
+    gchar *connPath;
+    GError *error = 0;
+
+    mConnService = EXAMPLE_ECHO_CONNECTION(g_object_new(
             EXAMPLE_TYPE_ECHO_CONNECTION,
             "account", "me@example.com",
             "protocol", "example",
-            NULL);
-    QCOMPARE(mConn->connect(), true);
+            0));
+    QVERIFY(mConnService != 0);
+    mBaseConnService = TP_BASE_CONNECTION(mConnService);
+    QVERIFY(mBaseConnService != 0);
+
+    QVERIFY(tp_base_connection_register(mBaseConnService,
+                "example", &name, &connPath, &error));
+    QVERIFY(error == 0);
+
+    QVERIFY(name != 0);
+    QVERIFY(connPath != 0);
+
+    mConnName = QLatin1String(name);
+    mConnPath = QLatin1String(connPath);
+
+    g_free(name);
+    g_free(connPath);
+
+    mConn = Connection::create(mConnName, mConnPath);
+    QCOMPARE(mConn->isReady(), false);
+
+    QVERIFY(connect(mConn->requestConnect(),
+                    SIGNAL(finished(Tp::PendingOperation*)),
+                    SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
+    QCOMPARE(mLoop->exec(), 0);
+    QCOMPARE(mConn->isReady(), true);
+    QCOMPARE(static_cast<uint>(mConn->status()),
+             static_cast<uint>(Connection::StatusConnected));
 
     // create a Channel by magic, rather than doing D-Bus round-trips for it
-    mContactRepo = tp_base_connection_get_handles(TP_BASE_CONNECTION(mConn->service()),
+
+    mContactRepo = tp_base_connection_get_handles(mBaseConnService,
             TP_HANDLE_TYPE_CONTACT);
     guint handle1 = tp_handle_ensure(mContactRepo, "someone1@localhost", 0, 0);
     guint handle2 = tp_handle_ensure(mContactRepo, "someone2@localhost", 0, 0);
@@ -97,47 +130,48 @@ void TestConferenceChan::initTestCase()
     QByteArray chanPath;
     GPtrArray *initialChannels = g_ptr_array_new();
 
-    mTextChan1Path = mConn->objectPath() + QLatin1String("/TextChannel/1");
-    chanPath = mTextChan1Path.toLatin1();
+    mTextChan1Path = mConnPath + QLatin1String("/TextChannel/1");
+    chanPath = mTextChan1Path.toAscii();
     mTextChan1Service = EXAMPLE_ECHO_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_CHANNEL,
-                "connection", mConn->service(),
+                "connection", mConnService,
                 "object-path", chanPath.data(),
                 "handle", handle1,
                 NULL));
     g_ptr_array_add(initialChannels, g_strdup(chanPath.data()));
 
-    mTextChan2Path = mConn->objectPath() + QLatin1String("/TextChannel/2");
-    chanPath = mTextChan2Path.toLatin1();
+    mTextChan2Path = mConnPath + QLatin1String("/TextChannel/2");
+    chanPath = mTextChan2Path.toAscii();
     mTextChan2Service = EXAMPLE_ECHO_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_CHANNEL,
-                "connection", mConn->service(),
+                "connection", mConnService,
                 "object-path", chanPath.data(),
                 "handle", handle2,
                 NULL));
     g_ptr_array_add(initialChannels, g_strdup(chanPath.data()));
 
     // let's not add this one to initial channels
-    mTextChan3Path = mConn->objectPath() + QLatin1String("/TextChannel/3");
-    chanPath = mTextChan3Path.toLatin1();
+    mTextChan3Path = mConnPath + QLatin1String("/TextChannel/3");
+    chanPath = mTextChan3Path.toAscii();
     mTextChan3Service = EXAMPLE_ECHO_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_CHANNEL,
-                "connection", mConn->service(),
+                "connection", mConnService,
                 "object-path", chanPath.data(),
                 "handle", handle3,
                 NULL));
 
-    mConferenceChanPath = mConn->objectPath() + QLatin1String("/ConferenceChannel");
-    chanPath = mConferenceChanPath.toLatin1();
-    mConferenceChanService = TP_TESTS_CONFERENCE_CHANNEL(g_object_new(
-                TP_TESTS_TYPE_CONFERENCE_CHANNEL,
-                "connection", mConn->service(),
+    mConferenceChanPath = mConnPath + QLatin1String("/ConferenceChannel");
+    chanPath = mConferenceChanPath.toAscii();
+    mConferenceChanService = EXAMPLE_CONFERENCE_CHANNEL(g_object_new(
+                EXAMPLE_TYPE_CONFERENCE_CHANNEL,
+                "connection", mConnService,
                 "object-path", chanPath.data(),
                 "initial-channels", initialChannels,
                 NULL));
 
-    g_ptr_array_foreach(initialChannels, (GFunc) g_free, NULL);
-    g_ptr_array_free(initialChannels, TRUE);
+    tp_handle_unref(mContactRepo, handle1);
+    tp_handle_unref(mContactRepo, handle2);
+    tp_handle_unref(mContactRepo, handle3);
 }
 
 void TestConferenceChan::init()
@@ -147,15 +181,7 @@ void TestConferenceChan::init()
 
 void TestConferenceChan::testConference()
 {
-    mChan = Channel::create(mConn->client(), mConferenceChanPath, QVariantMap());
-    QCOMPARE(mChan->isConference(), false);
-    QVERIFY(mChan->conferenceInitialInviteeContacts().isEmpty());
-    QVERIFY(mChan->conferenceChannels().isEmpty());
-    QVERIFY(mChan->conferenceInitialChannels().isEmpty());
-    QVERIFY(mChan->conferenceOriginalChannels().isEmpty());
-    QCOMPARE(mChan->supportsConferenceMerging(), false);
-    QCOMPARE(mChan->supportsConferenceSplitting(), false);
-
+    mChan = Channel::create(mConn, mConferenceChanPath, QVariantMap());
     QVERIFY(connect(mChan->becomeReady(),
                     SIGNAL(finished(Tp::PendingOperation*)),
                     SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
@@ -166,41 +192,23 @@ void TestConferenceChan::testConference()
     expectedObjectPaths << mTextChan1Path << mTextChan2Path;
 
     QStringList objectPaths;
-    Q_FOREACH (const ChannelPtr &channel, mChan->conferenceInitialChannels()) {
+    foreach (const ChannelPtr &channel, mChan->conferenceInitialChannels()) {
         objectPaths << channel->objectPath();
     }
     QCOMPARE(expectedObjectPaths, objectPaths);
 
     objectPaths.clear();
-    Q_FOREACH (const ChannelPtr &channel, mChan->conferenceChannels()) {
+    foreach (const ChannelPtr &channel, mChan->conferenceChannels()) {
         objectPaths << channel->objectPath();
     }
     QCOMPARE(expectedObjectPaths, objectPaths);
 
-    /*
-    // TODO - Properly check for initial invitee contacts if/when a test CM supports it
-    QVERIFY(!mChan->isReady(Channel::FeatureConferenceInitialInviteeContacts));
     QCOMPARE(mChan->conferenceInitialInviteeContacts(), Contacts());
 
-    QVERIFY(connect(mChan->becomeReady(Channel::FeatureConferenceInitialInviteeContacts),
-                    SIGNAL(finished(Tp::PendingOperation*)),
-                    SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
-    QCOMPARE(mLoop->exec(), 0);
-    QCOMPARE(mChan->isReady(Channel::FeatureConferenceInitialInviteeContacts), true);
+    QCOMPARE(mChan->hasConferenceInterface(), true);
+    QCOMPARE(mChan->hasMergeableConferenceInterface(), true);
 
-    QCOMPARE(mChan->conferenceInitialInviteeContacts(), Contacts());
-    */
-
-    QCOMPARE(mChan->supportsConferenceMerging(), true);
-    QCOMPARE(mChan->supportsConferenceSplitting(), false);
-    QVERIFY(connect(mChan->conferenceSplitChannel(),
-                    SIGNAL(finished(Tp::PendingOperation*)),
-                SLOT(expectFailure(Tp::PendingOperation*))));
-    QCOMPARE(mLoop->exec(), 0);
-    QCOMPARE(mLastError, TP_QT_ERROR_NOT_IMPLEMENTED);
-    QVERIFY(!mLastErrorMessage.isEmpty());
-
-    ChannelPtr otherChannel = Channel::create(mConn->client(), mTextChan3Path, QVariantMap());
+    ChannelPtr otherChannel = Channel::create(mConn, mTextChan3Path, QVariantMap());
 
     QVERIFY(connect(mChan.data(),
                     SIGNAL(conferenceChannelMerged(const Tp::ChannelPtr &)),
@@ -218,38 +226,10 @@ void TestConferenceChan::testConference()
 
     expectedObjectPaths << mTextChan3Path;
     objectPaths.clear();
-    Q_FOREACH (const ChannelPtr &channel, mChan->conferenceChannels()) {
+    foreach (const ChannelPtr &channel, mChan->conferenceChannels()) {
         objectPaths << channel->objectPath();
     }
     QCOMPARE(expectedObjectPaths, objectPaths);
-
-    QVERIFY(connect(mChan.data(),
-                    SIGNAL(conferenceChannelRemoved(const Tp::ChannelPtr &,
-                            const Tp::Channel::GroupMemberChangeDetails &)),
-                    SLOT(onConferenceChannelRemoved(const Tp::ChannelPtr &,
-                            const Tp::Channel::GroupMemberChangeDetails &))));
-    tp_tests_conference_channel_remove_channel (mConferenceChanService,
-            mChannelMerged->objectPath().toLatin1().data());
-    while (!mChannelRemovedDetailed) {
-        QCOMPARE(mLoop->exec(), 0);
-    }
-    QCOMPARE(mChannelRemovedDetailed, mChannelMerged);
-    QCOMPARE(mChannelRemovedDetailedDetails.allDetails().isEmpty(), false);
-    QCOMPARE(qdbus_cast<int>(mChannelRemovedDetailedDetails.allDetails().value(
-                    QLatin1String("domain-specific-detail-uint"))), 3);
-    QCOMPARE(mChannelRemovedDetailedDetails.hasActor(), true);
-    QCOMPARE(mChannelRemovedDetailedDetails.actor(), mChan->groupSelfContact());
-
-    expectedObjectPaths.clear();
-    expectedObjectPaths << mTextChan1Path << mTextChan2Path;
-    objectPaths.clear();
-    Q_FOREACH (const ChannelPtr &channel, mChan->conferenceChannels()) {
-        objectPaths << channel->objectPath();
-    }
-    QCOMPARE(expectedObjectPaths, objectPaths);
-
-    mChan.reset();
-    mChannelMerged.reset();
 }
 
 void TestConferenceChan::cleanup()
@@ -259,8 +239,22 @@ void TestConferenceChan::cleanup()
 
 void TestConferenceChan::cleanupTestCase()
 {
-    QCOMPARE(mConn->disconnect(), true);
-    delete mConn;
+    if (mConn) {
+        // Disconnect and wait for the readiness change
+        QVERIFY(connect(mConn->requestDisconnect(),
+                        SIGNAL(finished(Tp::PendingOperation*)),
+                        SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
+        QCOMPARE(mLoop->exec(), 0);
+
+        if (mConn->isValid()) {
+            QVERIFY(connect(mConn.data(),
+                            SIGNAL(invalidated(Tp::DBusProxy *,
+                                               const QString &, const QString &)),
+                            mLoop,
+                            SLOT(quit())));
+            QCOMPARE(mLoop->exec(), 0);
+        }
+    }
 
     if (mTextChan1Service != 0) {
         g_object_unref(mTextChan1Service);
@@ -277,6 +271,12 @@ void TestConferenceChan::cleanupTestCase()
         mConferenceChanService = 0;
     }
 
+    if (mConnService != 0) {
+        mBaseConnService = 0;
+        g_object_unref(mConnService);
+        mConnService = 0;
+    }
+
     cleanupTestCaseImpl();
 }
 
