@@ -5,21 +5,15 @@
 #include <QtDBus>
 #include <QtTest>
 
-#define TP_QT_ENABLE_LOWLEVEL_API
-
-#include <TelepathyQt/ChannelFactory>
-#include <TelepathyQt/Connection>
-#include <TelepathyQt/ConnectionLowlevel>
-#include <TelepathyQt/Contact>
-#include <TelepathyQt/ContactFactory>
-#include <TelepathyQt/ContactManager>
-#include <TelepathyQt/PendingContacts>
-#include <TelepathyQt/PendingVoid>
-#include <TelepathyQt/PendingReady>
-#include <TelepathyQt/Presence>
-#include <TelepathyQt/ReferencedHandles>
-#include <TelepathyQt/Debug>
-#include <TelepathyQt/Types>
+#include <TelepathyQt4/Connection>
+#include <TelepathyQt4/Contact>
+#include <TelepathyQt4/ContactManager>
+#include <TelepathyQt4/PendingContacts>
+#include <TelepathyQt4/PendingVoid>
+#include <TelepathyQt4/PendingReady>
+#include <TelepathyQt4/ReferencedHandles>
+#include <TelepathyQt4/Debug>
+#include <TelepathyQt4/Types>
 
 #include <telepathy-glib/debug.h>
 
@@ -40,7 +34,7 @@ public:
     }
 
 protected Q_SLOTS:
-    void expectConnReady(Tp::ConnectionStatus, Tp::ConnectionStatusReason);
+    void expectConnReady(Tp::Connection::Status, Tp::ConnectionStatusReason);
     void expectConnInvalidated();
     void expectPendingContactsFinished(Tp::PendingOperation *);
 
@@ -68,18 +62,18 @@ private:
     Tp::UIntList mInvalidHandles;
 };
 
-void TestContacts::expectConnReady(Tp::ConnectionStatus newStatus,
+void TestContacts::expectConnReady(Tp::Connection::Status newStatus,
         Tp::ConnectionStatusReason newStatusReason)
 {
     switch (newStatus) {
-    case ConnectionStatusDisconnected:
+    case Connection::StatusDisconnected:
         qWarning() << "Disconnected";
         mLoop->exit(1);
         break;
-    case ConnectionStatusConnecting:
+    case Connection::StatusConnecting:
         /* do nothing */
         break;
-    case ConnectionStatusConnected:
+    case Connection::StatusConnected:
         qDebug() << "Ready";
         mLoop->exit(0);
         break;
@@ -98,8 +92,26 @@ void TestContacts::expectConnInvalidated()
 
 void TestContacts::expectPendingContactsFinished(PendingOperation *op)
 {
-    TEST_VERIFY_OP(op);
+    if (!op->isFinished()) {
+        qWarning() << "unfinished";
+        mLoop->exit(1);
+        return;
+    }
 
+    if (op->isError()) {
+        qWarning().nospace() << op->errorName()
+            << ": " << op->errorMessage();
+        mLoop->exit(2);
+        return;
+    }
+
+    if (!op->isValid()) {
+        qWarning() << "inconsistent results";
+        mLoop->exit(3);
+        return;
+    }
+
+    qDebug() << "finished";
     PendingContacts *pending = qobject_cast<PendingContacts *>(op);
     mContacts = pending->contacts();
 
@@ -127,7 +139,7 @@ void TestContacts::initTestCase()
             TP_TESTS_TYPE_CONTACTS_CONNECTION,
             "account", "me@example.com",
             "protocol", "simple",
-            NULL));
+            0));
     QVERIFY(mConnService != 0);
     QVERIFY(tp_base_connection_register(TP_BASE_CONNECTION(mConnService), "contacts", &name,
                 &connPath, &error));
@@ -142,12 +154,10 @@ void TestContacts::initTestCase()
     g_free(name);
     g_free(connPath);
 
-    mConn = Connection::create(mConnName, mConnPath,
-            ChannelFactory::create(QDBusConnection::sessionBus()),
-            ContactFactory::create());
+    mConn = Connection::create(mConnName, mConnPath);
     QCOMPARE(mConn->isReady(), false);
 
-    mConn->lowlevel()->requestConnect();
+    mConn->requestConnect();
 
     Features features = Features() << Connection::FeatureSelfContact;
     QVERIFY(connect(mConn->becomeReady(features),
@@ -156,16 +166,16 @@ void TestContacts::initTestCase()
     QCOMPARE(mLoop->exec(), 0);
     QCOMPARE(mConn->isReady(features), true);
 
-    if (mConn->status() != ConnectionStatusConnected) {
+    if (mConn->status() != Connection::StatusConnected) {
         QVERIFY(connect(mConn.data(),
-                        SIGNAL(statusChanged(Tp::ConnectionStatus, Tp::ConnectionStatusReason)),
-                        SLOT(expectConnReady(Tp::ConnectionStatus, Tp::ConnectionStatusReason))));
+                        SIGNAL(statusChanged(Tp::Connection::Status, Tp::ConnectionStatusReason)),
+                        SLOT(expectConnReady(Tp::Connection::Status, Tp::ConnectionStatusReason))));
         QCOMPARE(mLoop->exec(), 0);
         QVERIFY(disconnect(mConn.data(),
-                           SIGNAL(statusChanged(Tp::ConnectionStatus, Tp::ConnectionStatusReason)),
+                           SIGNAL(statusChanged(Tp::Connection::Status, Tp::ConnectionStatusReason)),
                            this,
-                           SLOT(expectConnReady(Tp::ConnectionStatus, Tp::ConnectionStatusReason))));
-        QCOMPARE(mConn->status(), ConnectionStatusConnected);
+                           SLOT(expectConnReady(Tp::Connection::Status, Tp::ConnectionStatusReason))));
+        QCOMPARE(mConn->status(), Connection::StatusConnected);
     }
 }
 
@@ -178,25 +188,22 @@ void TestContacts::testSupport()
 {
     QCOMPARE(mConn->contactManager()->connection(), mConn);
 
-    QVERIFY(!mConn->lowlevel()->contactAttributeInterfaces().isEmpty());
+    QVERIFY(!mConn->contactAttributeInterfaces().isEmpty());
 
-    QVERIFY(mConn->lowlevel()->contactAttributeInterfaces().contains(
-                TP_QT_IFACE_CONNECTION));
-    QVERIFY(mConn->lowlevel()->contactAttributeInterfaces().contains(
-                TP_QT_IFACE_CONNECTION_INTERFACE_ALIASING));
-    QVERIFY(mConn->lowlevel()->contactAttributeInterfaces().contains(
-                TP_QT_IFACE_CONNECTION_INTERFACE_AVATARS));
-    QVERIFY(mConn->lowlevel()->contactAttributeInterfaces().contains(
-                TP_QT_IFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE));
-    QVERIFY(!mConn->lowlevel()->contactAttributeInterfaces().contains(
-                QLatin1String("org.freedesktop.Telepathy.Connection.Interface.Addressing.DRAFT")));
+    QVERIFY(mConn->contactAttributeInterfaces().contains(
+                QLatin1String(TELEPATHY_INTERFACE_CONNECTION)));
+    QVERIFY(mConn->contactAttributeInterfaces().contains(
+                QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_ALIASING)));
+    QVERIFY(mConn->contactAttributeInterfaces().contains(
+                QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_AVATARS)));
+    QVERIFY(mConn->contactAttributeInterfaces().contains(
+                QLatin1String(TELEPATHY_INTERFACE_CONNECTION_INTERFACE_SIMPLE_PRESENCE)));
 
-    Features supportedFeatures = mConn->contactManager()->supportedFeatures();
+    QSet<Contact::Feature> supportedFeatures = mConn->contactManager()->supportedFeatures();
     QVERIFY(!supportedFeatures.isEmpty());
     QVERIFY(supportedFeatures.contains(Contact::FeatureAlias));
     QVERIFY(supportedFeatures.contains(Contact::FeatureAvatarToken));
     QVERIFY(supportedFeatures.contains(Contact::FeatureSimplePresence));
-    QVERIFY(!supportedFeatures.contains(Contact::FeatureAddresses));
 }
 
 void TestContacts::testSelfContact()
@@ -207,11 +214,11 @@ void TestContacts::testSelfContact()
     QCOMPARE(selfContact->handle()[0], mConn->selfHandle());
     QCOMPARE(selfContact->id(), QString(QLatin1String("me@example.com")));
 
-    Features features = Features() << Contact::FeatureAlias <<
-        Contact::FeatureAvatarToken <<
-        Contact::FeatureSimplePresence;
     QVERIFY(connect(selfContact->manager()->upgradeContacts(
-                        QList<ContactPtr>() << selfContact, features),
+                        QList<ContactPtr>() << selfContact,
+                        QSet<Contact::Feature>() << Contact::FeatureAlias
+                            << Contact::FeatureAvatarToken
+                            << Contact::FeatureSimplePresence),
                     SIGNAL(finished(Tp::PendingOperation*)),
                     SLOT(expectPendingContactsFinished(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
@@ -220,24 +227,9 @@ void TestContacts::testSelfContact()
 
     QVERIFY(!selfContact->isAvatarTokenKnown());
 
-    QCOMPARE(selfContact->presence().status(), QString(QLatin1String("available")));
-    QCOMPARE(selfContact->presence().type(), Tp::ConnectionPresenceTypeAvailable);
-    QCOMPARE(selfContact->presence().statusMessage(), QString(QLatin1String("")));
-
-    features << Contact::FeatureInfo;
-    QVERIFY(connect(selfContact->manager()->upgradeContacts(
-                        QList<ContactPtr>() << selfContact, features),
-                    SIGNAL(finished(Tp::PendingOperation*)),
-                    SLOT(expectPendingContactsFinished(Tp::PendingOperation*))));
-    QCOMPARE(mLoop->exec(), 0);
-
-    QCOMPARE(selfContact->alias(), QString(QLatin1String("me@example.com")));
-
-    QVERIFY(!selfContact->isAvatarTokenKnown());
-
-    QCOMPARE(selfContact->presence().status(), QString(QLatin1String("available")));
-    QCOMPARE(selfContact->presence().type(), Tp::ConnectionPresenceTypeAvailable);
-    QCOMPARE(selfContact->presence().statusMessage(), QString(QLatin1String("")));
+    QCOMPARE(selfContact->presenceStatus(), QString(QLatin1String("available")));
+    QCOMPARE(selfContact->presenceType(), uint(Tp::ConnectionPresenceTypeAvailable));
+    QCOMPARE(selfContact->presenceMessage(), QString(QLatin1String("")));
 }
 
 void TestContacts::testForHandles()
@@ -266,7 +258,7 @@ void TestContacts::testForHandles()
 
     // Test the closure accessors
     QCOMPARE(pending->manager(), mConn->contactManager());
-    QCOMPARE(pending->features(), Features());
+    QCOMPARE(pending->features(), QSet<Contact::Feature>());
 
     QVERIFY(pending->isForHandles());
     QVERIFY(!pending->isForIdentifiers());
@@ -291,8 +283,8 @@ void TestContacts::testForHandles()
     for (int i = 0; i < 3; i++) {
         QVERIFY(mContacts[i] != NULL);
         QCOMPARE(mContacts[i]->manager(), mConn->contactManager());
-        QCOMPARE(mContacts[i]->requestedFeatures(), Features());
-        QCOMPARE(mContacts[i]->actualFeatures(), Features());
+        QCOMPARE(mContacts[i]->requestedFeatures(), QSet<Contact::Feature>());
+        QCOMPARE(mContacts[i]->actualFeatures(), QSet<Contact::Feature>());
     }
 
     QCOMPARE(mContacts[0]->handle()[0], handles[0]);
@@ -333,6 +325,16 @@ void TestContacts::testForHandles()
     mContacts.clear();
     mLoop->processEvents();
     processDBusQueue(mConn.data());
+
+    // Unref the handles we created service-side
+    tp_handle_unref(serviceRepo, handles[0]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[0], NULL));
+    tp_handle_unref(serviceRepo, handles[1]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[1], NULL));
+    tp_handle_unref(serviceRepo, handles[2]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[2], NULL));
+    tp_handle_unref(serviceRepo, handles[3]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[3], NULL));
 }
 
 void TestContacts::testForIdentifiers()
@@ -374,7 +376,7 @@ void TestContacts::testForIdentifiers()
 
     // Test the closure accessors
     QCOMPARE(pending->manager(), mConn->contactManager());
-    QCOMPARE(pending->features(), Features());
+    QCOMPARE(pending->features(), QSet<Contact::Feature>());
 
     QVERIFY(!pending->isForHandles());
     QVERIFY(pending->isForIdentifiers());
@@ -395,8 +397,8 @@ void TestContacts::testForIdentifiers()
         QVERIFY(mContacts[i] != NULL);
         QCOMPARE(mContacts[i]->manager(), mConn->contactManager());
         QVERIFY(tp_handle_is_valid(serviceRepo, mContacts[i]->handle()[0], NULL));
-        QCOMPARE(mContacts[i]->requestedFeatures(), Features());
-        QCOMPARE(mContacts[i]->actualFeatures(), Features());
+        QCOMPARE(mContacts[i]->requestedFeatures(), QSet<Contact::Feature>());
+        QCOMPARE(mContacts[i]->actualFeatures(), QSet<Contact::Feature>());
     }
 
     QCOMPARE(mContacts[0]->id(), QString(QLatin1String("alice")));
@@ -411,6 +413,11 @@ void TestContacts::testForIdentifiers()
     mContacts.clear();
     mLoop->processEvents();
     processDBusQueue(mConn.data());
+
+    // Check that their handles are in fact released
+    foreach (uint handle, saveHandles) {
+        QVERIFY(!tp_handle_is_valid(serviceRepo, handle, NULL));
+    }
 }
 
 void TestContacts::testFeatures()
@@ -452,7 +459,7 @@ void TestContacts::testFeatures()
         "Having some carrots",
         "Done building for life, yay",
     };
-    Features features = Features()
+    QSet<Contact::Feature> features = QSet<Contact::Feature>()
         << Contact::FeatureAlias
         << Contact::FeatureAvatarToken
         << Contact::FeatureSimplePresence;
@@ -494,7 +501,7 @@ void TestContacts::testFeatures()
 
         QVERIFY(mContacts[i]->actualFeatures().contains(Contact::FeatureAvatarToken));
         QVERIFY(mContacts[i]->actualFeatures().contains(Contact::FeatureSimplePresence));
-        QCOMPARE(mContacts[i]->presence().statusMessage(), QString(QLatin1String(initialMessages[i])));
+        QCOMPARE(mContacts[i]->presenceMessage(), QString(QLatin1String(initialMessages[i])));
     }
 
     // Check that there's no known avatar token for the first contact, but that there is for the
@@ -507,13 +514,13 @@ void TestContacts::testFeatures()
     QCOMPARE(mContacts[1]->avatarToken(), QString(QLatin1String(initialTokens[0])));
     QCOMPARE(mContacts[2]->avatarToken(), QString(QLatin1String(initialTokens[1])));
 
-    QCOMPARE(mContacts[0]->presence().status(), QString(QLatin1String("available")));
-    QCOMPARE(mContacts[1]->presence().status(), QString(QLatin1String("busy")));
-    QCOMPARE(mContacts[2]->presence().status(), QString(QLatin1String("away")));
+    QCOMPARE(mContacts[0]->presenceStatus(), QString(QLatin1String("available")));
+    QCOMPARE(mContacts[1]->presenceStatus(), QString(QLatin1String("busy")));
+    QCOMPARE(mContacts[2]->presenceStatus(), QString(QLatin1String("away")));
 
-    QCOMPARE(mContacts[0]->presence().type(), Tp::ConnectionPresenceTypeAvailable);
-    QCOMPARE(mContacts[1]->presence().type(), Tp::ConnectionPresenceTypeBusy);
-    QCOMPARE(mContacts[2]->presence().type(), Tp::ConnectionPresenceTypeAway);
+    QCOMPARE(mContacts[0]->presenceType(), uint(Tp::ConnectionPresenceTypeAvailable));
+    QCOMPARE(mContacts[1]->presenceType(), uint(Tp::ConnectionPresenceTypeBusy));
+    QCOMPARE(mContacts[2]->presenceType(), uint(Tp::ConnectionPresenceTypeAway));
 
     // Change some of the contacts to a new set of attributes
     tp_tests_contacts_connection_change_aliases(mConnService, 2, handles.toVector().constData(),
@@ -547,22 +554,30 @@ void TestContacts::testFeatures()
     QCOMPARE(mContacts[1]->avatarToken(), QString(QLatin1String(latterTokens[1])));
     QCOMPARE(mContacts[2]->avatarToken(), QString(QLatin1String(initialTokens[1])));
 
-    QCOMPARE(mContacts[0]->presence().status(), QString(QLatin1String("away")));
-    QCOMPARE(mContacts[1]->presence().status(), QString(QLatin1String("available")));
-    QCOMPARE(mContacts[2]->presence().status(), QString(QLatin1String("away")));
+    QCOMPARE(mContacts[0]->presenceStatus(), QString(QLatin1String("away")));
+    QCOMPARE(mContacts[1]->presenceStatus(), QString(QLatin1String("available")));
+    QCOMPARE(mContacts[2]->presenceStatus(), QString(QLatin1String("away")));
 
-    QCOMPARE(mContacts[0]->presence().type(), Tp::ConnectionPresenceTypeAway);
-    QCOMPARE(mContacts[1]->presence().type(), Tp::ConnectionPresenceTypeAvailable);
-    QCOMPARE(mContacts[2]->presence().type(), Tp::ConnectionPresenceTypeAway);
+    QCOMPARE(mContacts[0]->presenceType(), uint(Tp::ConnectionPresenceTypeAway));
+    QCOMPARE(mContacts[1]->presenceType(), uint(Tp::ConnectionPresenceTypeAvailable));
+    QCOMPARE(mContacts[2]->presenceType(), uint(Tp::ConnectionPresenceTypeAway));
 
-    QCOMPARE(mContacts[0]->presence().statusMessage(), QString(QLatin1String(latterMessages[0])));
-    QCOMPARE(mContacts[1]->presence().statusMessage(), QString(QLatin1String(latterMessages[1])));
-    QCOMPARE(mContacts[2]->presence().statusMessage(), QString(QLatin1String(initialMessages[2])));
+    QCOMPARE(mContacts[0]->presenceMessage(), QString(QLatin1String(latterMessages[0])));
+    QCOMPARE(mContacts[1]->presenceMessage(), QString(QLatin1String(latterMessages[1])));
+    QCOMPARE(mContacts[2]->presenceMessage(), QString(QLatin1String(initialMessages[2])));
 
     // Make the contacts go out of scope, starting releasing their handles, and finish that
     mContacts.clear();
     mLoop->processEvents();
     processDBusQueue(mConn.data());
+
+    // Unref the handles we created service-side
+    tp_handle_unref(serviceRepo, handles[0]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[0], NULL));
+    tp_handle_unref(serviceRepo, handles[1]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[1], NULL));
+    tp_handle_unref(serviceRepo, handles[2]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[2], NULL));
 }
 
 void TestContacts::testFeaturesNotRequested()
@@ -599,13 +614,23 @@ void TestContacts::testFeaturesNotRequested()
         QVERIFY(!contact->isAvatarTokenKnown());
         QCOMPARE(contact->avatarToken(), QString(QLatin1String("")));
 
-        QCOMPARE(contact->presence().isValid(), false);
+        QCOMPARE(contact->presenceStatus(), QString(QLatin1String("unknown")));
+        QCOMPARE(contact->presenceType(), uint(Tp::ConnectionPresenceTypeUnknown));
+        QCOMPARE(contact->presenceMessage(), QString(QLatin1String("")));
     }
 
     // Make the contacts go out of scope, starting releasing their handles, and finish that
     mContacts.clear();
     mLoop->processEvents();
     processDBusQueue(mConn.data());
+
+    // Unref the handles we created service-side
+    tp_handle_unref(serviceRepo, handles[0]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[0], NULL));
+    tp_handle_unref(serviceRepo, handles[1]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[1], NULL));
+    tp_handle_unref(serviceRepo, handles[2]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[2], NULL));
 }
 
 void TestContacts::testUpgrade()
@@ -659,7 +684,7 @@ void TestContacts::testUpgrade()
     QList<ContactPtr> saveContacts = mContacts;
 
     // Upgrade them
-    Features features = Features()
+    QSet<Contact::Feature> features = QSet<Contact::Feature>()
         << Contact::FeatureAlias
         << Contact::FeatureAvatarToken
         << Contact::FeatureSimplePresence;
@@ -699,22 +724,30 @@ void TestContacts::testUpgrade()
         QCOMPARE(mContacts[i]->avatarToken(), QString(QLatin1String(tokens[i])));
 
         QVERIFY(mContacts[i]->actualFeatures().contains(Contact::FeatureSimplePresence));
-        QCOMPARE(mContacts[i]->presence().statusMessage(), QString(QLatin1String(messages[i])));
+        QCOMPARE(mContacts[i]->presenceMessage(), QString(QLatin1String(messages[i])));
     }
 
-    QCOMPARE(mContacts[0]->presence().status(), QString(QLatin1String("available")));
-    QCOMPARE(mContacts[1]->presence().status(), QString(QLatin1String("busy")));
-    QCOMPARE(mContacts[2]->presence().status(), QString(QLatin1String("away")));
+    QCOMPARE(mContacts[0]->presenceStatus(), QString(QLatin1String("available")));
+    QCOMPARE(mContacts[1]->presenceStatus(), QString(QLatin1String("busy")));
+    QCOMPARE(mContacts[2]->presenceStatus(), QString(QLatin1String("away")));
 
-    QCOMPARE(mContacts[0]->presence().type(), Tp::ConnectionPresenceTypeAvailable);
-    QCOMPARE(mContacts[1]->presence().type(), Tp::ConnectionPresenceTypeBusy);
-    QCOMPARE(mContacts[2]->presence().type(), Tp::ConnectionPresenceTypeAway);
+    QCOMPARE(mContacts[0]->presenceType(), uint(Tp::ConnectionPresenceTypeAvailable));
+    QCOMPARE(mContacts[1]->presenceType(), uint(Tp::ConnectionPresenceTypeBusy));
+    QCOMPARE(mContacts[2]->presenceType(), uint(Tp::ConnectionPresenceTypeAway));
 
     // Make the contacts go out of scope, starting releasing their handles, and finish that
     saveContacts.clear();
     mContacts.clear();
     mLoop->processEvents();
     processDBusQueue(mConn.data());
+
+    // Unref the handles we created service-side
+    tp_handle_unref(serviceRepo, handles[0]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[0], NULL));
+    tp_handle_unref(serviceRepo, handles[1]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[1], NULL));
+    tp_handle_unref(serviceRepo, handles[2]);
+    QVERIFY(!tp_handle_is_valid(serviceRepo, handles[2], NULL));
 }
 
 void TestContacts::testSelfContactFallback()
@@ -728,7 +761,7 @@ void TestContacts::testSelfContactFallback()
             TP_TESTS_TYPE_SIMPLE_CONNECTION,
             "account", "me@example.com",
             "protocol", "simple",
-            NULL));
+            0));
     QVERIFY(connService != 0);
     QVERIFY(tp_base_connection_register(TP_BASE_CONNECTION(connService), "simple", &name,
                 &connPath, &error));
@@ -737,16 +770,16 @@ void TestContacts::testSelfContactFallback()
     QVERIFY(name != 0);
     QVERIFY(connPath != 0);
 
-    ConnectionPtr conn = Connection::create(QLatin1String(name), QLatin1String(connPath),
-            ChannelFactory::create(QDBusConnection::sessionBus()),
-            ContactFactory::create());
+    ConnectionPtr conn = Connection::create(QLatin1String(name), QLatin1String(connPath));
     g_free(name);
     g_free(connPath);
 
     QCOMPARE(conn->isReady(), false);
 
+    conn->requestConnect();
+
     Features features = Features() << Connection::FeatureSelfContact;
-    QVERIFY(connect(conn->lowlevel()->requestConnect(features),
+    QVERIFY(connect(conn->becomeReady(features),
                 SIGNAL(finished(Tp::PendingOperation*)),
                 SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
@@ -759,20 +792,7 @@ void TestContacts::testSelfContactFallback()
     QCOMPARE(selfContact->id(), QString(QLatin1String("me@example.com")));
     QCOMPARE(selfContact->alias(), QString(QLatin1String("me@example.com")));
     QVERIFY(!selfContact->isAvatarTokenKnown());
-    QCOMPARE(selfContact->presence().isValid(), false);
-
-    tp_tests_simple_connection_inject_disconnect(connService);
-
-    if (conn->isValid()) {
-        QVERIFY(connect(conn.data(),
-                    SIGNAL(invalidated(Tp::DBusProxy *,
-                            const QString &, const QString &)),
-                    mLoop,
-                    SLOT(quit())));
-        QCOMPARE(mLoop->exec(), 0);
-    }
-
-    g_object_unref(connService);
+    QCOMPARE(selfContact->presenceStatus(), QString(QLatin1String("unknown")));
 }
 
 void TestContacts::cleanup()
@@ -792,7 +812,7 @@ void TestContacts::cleanupTestCase()
 
     if (mConn) {
         // Disconnect and wait for the readiness change
-        QVERIFY(connect(mConn->lowlevel()->requestDisconnect(),
+        QVERIFY(connect(mConn->requestDisconnect(),
                     SIGNAL(finished(Tp::PendingOperation*)),
                     SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
         QCOMPARE(mLoop->exec(), 0);
