@@ -100,12 +100,12 @@ private:
 
 QString TestStatefulProxy::wellKnownName()
 {
-    return "org.freedesktop.Telepathy.Qt4.TestStatefulProxy";
+    return QLatin1String("org.freedesktop.Telepathy.Qt4.TestStatefulProxy");
 }
 
 QString TestStatefulProxy::objectPath()
 {
-    return "/org/freedesktop/Telepathy/Qt4/TestStatefulProxy/Object";
+    return QLatin1String("/org/freedesktop/Telepathy/Qt4/TestStatefulProxy/Object");
 }
 
 TestStatefulProxy::TestStatefulProxy(QObject *parent)
@@ -188,14 +188,14 @@ void TestStatefulProxy::testBasics()
                 this, SLOT(expectInvalidated(
                         Tp::DBusProxy *,
                         const QString &, const QString &))));
-    mProxy->invalidate("com.example.DomainSpecificError",
-            "Because I said so");
+    mProxy->invalidate(QLatin1String("com.example.DomainSpecificError"),
+            QLatin1String("Because I said so"));
 
     QVERIFY(!mProxy->isValid());
     QCOMPARE(mProxy->invalidationReason(),
-            QString::fromAscii("com.example.DomainSpecificError"));
+            QLatin1String("com.example.DomainSpecificError"));
     QCOMPARE(mProxy->invalidationMessage(),
-            QString::fromAscii("Because I said so"));
+            QLatin1String("Because I said so"));
 
     // FIXME: ideally, the method call would already fail synchronously at
     // this point - after all, the proxy already knows it's dead
@@ -220,9 +220,9 @@ void TestStatefulProxy::testBasics()
 
     QCOMPARE(mInvalidated, 1);
     QCOMPARE(mSignalledInvalidationReason,
-            QString::fromAscii("com.example.DomainSpecificError"));
+            QLatin1String("com.example.DomainSpecificError"));
     QCOMPARE(mSignalledInvalidationMessage,
-            QString::fromAscii("Because I said so"));
+            QLatin1String("Because I said so"));
 
     // the low-level proxy made from the high-level proxy now returns an
     // error, synchronously
@@ -264,7 +264,7 @@ void TestStatefulProxy::testNameOwnerChanged()
 {
     QString otherUniqueName = QDBusConnection::connectToBus(
             QDBusConnection::SessionBus,
-            "another unique name").baseService();
+            QLatin1String("another unique name")).baseService();
 
     mProxy = new MyStatefulDBusProxy(QDBusConnection::sessionBus(),
             otherUniqueName, objectPath());
@@ -279,7 +279,7 @@ void TestStatefulProxy::testNameOwnerChanged()
                 this, SLOT(expectInvalidated(
                         Tp::DBusProxy *,
                         const QString &, const QString &))));
-    QDBusConnection::disconnectFromBus("another unique name");
+    QDBusConnection::disconnectFromBus(QLatin1String("another unique name"));
     QCOMPARE(mLoop->exec(), EXPECT_INVALIDATED_SUCCESS);
     QVERIFY(disconnect(mProxy, SIGNAL(invalidated(
                         Tp::DBusProxy *,
@@ -291,9 +291,9 @@ void TestStatefulProxy::testNameOwnerChanged()
     QCOMPARE(mInvalidated, 1);
     QVERIFY(!mProxy->isValid());
     QCOMPARE(mProxy->invalidationReason(),
-            QString::fromAscii(TELEPATHY_DBUS_ERROR_NAME_HAS_NO_OWNER));
+            QLatin1String(TELEPATHY_DBUS_ERROR_NAME_HAS_NO_OWNER));
     QCOMPARE(mSignalledInvalidationReason,
-            QString::fromAscii(TELEPATHY_DBUS_ERROR_NAME_HAS_NO_OWNER));
+            QLatin1String(TELEPATHY_DBUS_ERROR_NAME_HAS_NO_OWNER));
     QVERIFY(!mProxy->invalidationMessage().isEmpty());
     QCOMPARE(mProxy->invalidationMessage(), mSignalledInvalidationMessage);
 }
