@@ -1,23 +1,26 @@
-// We need to use the deprecated TpTextMixin here to test compatibility functionality
-#define _TP_IGNORE_DEPRECATIONS
+#include <QtCore/QDebug>
+#include <QtCore/QTimer>
 
-#include <tests/lib/test.h>
+#include <QtDBus/QtDBus>
 
-#include <tests/lib/glib-helpers/test-conn-helper.h>
+#include <QtTest/QtTest>
+
+#include <TelepathyQt4/Connection>
+#include <TelepathyQt4/Message>
+#include <TelepathyQt4/PendingReady>
+#include <TelepathyQt4/ReceivedMessage>
+#include <TelepathyQt4/TextChannel>
+#include <TelepathyQt4/Debug>
+
+#include <telepathy-glib/debug.h>
 
 #include <tests/lib/glib/contacts-conn.h>
 #include <tests/lib/glib/echo/chan.h>
 #include <tests/lib/glib/echo2/chan.h>
-
-#include <TelepathyQt/Connection>
-#include <TelepathyQt/Message>
-#include <TelepathyQt/PendingReady>
-#include <TelepathyQt/ReceivedMessage>
-#include <TelepathyQt/TextChannel>
-
-#include <telepathy-glib/debug.h>
+#include <tests/lib/test.h>
 
 using namespace Tp;
+using Tp::UIntList;
 
 struct SentMessageDetails
 {
@@ -37,10 +40,9 @@ class TestTextChan : public Test
 public:
     TestTextChan(QObject *parent = 0)
         : Test(parent),
-          mConn(0), mContactRepo(0),
-          mTextChanService(0), mMessagesChanService(0),
-          mGotChatStateChanged(false),
-          mChatStateChangedState((ChannelChatState) -1)
+          // service side (telepathy-glib)
+          mConnService(0), mBaseConnService(0), mContactRepo(0),
+            mTextChanService(0), mMessagesChanService(0)
     { }
 
 protected Q_SLOTS:
@@ -48,8 +50,6 @@ protected Q_SLOTS:
     void onMessageRemoved(const Tp::ReceivedMessage &);
     void onMessageSent(const Tp::Message &,
             Tp::MessageSendingFlags, const QString &);
-    void onChatStateChanged(const Tp::ContactPtr &contact,
-            Tp::ChannelChatState state);
 
 private Q_SLOTS:
     void initTestCase();
@@ -65,59 +65,48 @@ private:
     void commonTest(bool withMessages);
     void sendText(const char *text);
 
-    TestConnHelper *mConn;
-    TpHandleRepoIface *mContactRepo;
-    ContactPtr mContact;
-    TextChannelPtr mChan;
-    ExampleEchoChannel *mTextChanService;
-    QString mTextChanPath;
-    ExampleEcho2Channel *mMessagesChanService;
-    QString mMessagesChanPath;
     QList<SentMessageDetails> sent;
     QList<ReceivedMessage> received;
     QList<ReceivedMessage> removed;
-    bool mGotChatStateChanged;
-    ContactPtr mChatStateChangedContact;
-    ChannelChatState mChatStateChangedState;
+
+    TpTestsContactsConnection *mConnService;
+    TpBaseConnection *mBaseConnService;
+    TpHandleRepoIface *mContactRepo;
+    ExampleEchoChannel *mTextChanService;
+    ExampleEcho2Channel *mMessagesChanService;
+
+    ConnectionPtr mConn;
+    TextChannelPtr mChan;
+    QString mTextChanPath;
+    QString mMessagesChanPath;
+    QString mConnName;
+    QString mConnPath;
 };
 
 void TestTextChan::onMessageReceived(const ReceivedMessage &message)
 {
-    qDebug() << "message received";
     received << message;
     mLoop->exit(0);
 }
 
 void TestTextChan::onMessageRemoved(const ReceivedMessage &message)
 {
-    qDebug() << "message removed";
     removed << message;
 }
 
 void TestTextChan::onMessageSent(const Tp::Message &message,
         Tp::MessageSendingFlags flags, const QString &token)
 {
-    qDebug() << "message sent";
     sent << SentMessageDetails(message, flags, token);
 }
 
-void TestTextChan::onChatStateChanged(const Tp::ContactPtr &contact,
-        Tp::ChannelChatState state)
-{
-    mGotChatStateChanged = true;
-    mChatStateChangedContact = contact;
-    mChatStateChangedState = state;
-}
-
 void TestTextChan::sendText(const char *text)
 {
-    qDebug() << "sending message:" << text;
     QVERIFY(connect(mChan->send(QLatin1String(text),
                     Tp::ChannelTextMessageTypeNormal),
                 SIGNAL(finished(Tp::PendingOperation *)),
                 SLOT(expectSuccessfulCall(Tp::PendingOperation *))));
     QCOMPARE(mLoop->exec(), 0);
-    qDebug() << "message send mainloop finished";
 }
 
 void TestTextChan::initTestCase()
@@ -129,38 +118,70 @@ void TestTextChan::initTestCase()
     tp_debug_set_flags("all");
     dbus_g_bus_get(DBUS_BUS_STARTER, 0);
 
-    mConn = new TestConnHelper(this,
+    gchar *name;
+    gchar *connPath;
+    GError *error = 0;
+
+    mConnService = TP_TESTS_CONTACTS_CONNECTION(g_object_new(
             TP_TESTS_TYPE_CONTACTS_CONNECTION,
             "account", "me@example.com",
             "protocol", "example",
-            NULL);
-    QCOMPARE(mConn->connect(), true);
+            0));
+    QVERIFY(mConnService != 0);
+    mBaseConnService = TP_BASE_CONNECTION(mConnService);
+    QVERIFY(mBaseConnService != 0);
 
-    mContactRepo = tp_base_connection_get_handles(TP_BASE_CONNECTION(mConn->service()),
+    QVERIFY(tp_base_connection_register(mBaseConnService,
+                "example", &name, &connPath, &error));
+    QVERIFY(error == 0);
+
+    QVERIFY(name != 0);
+    QVERIFY(connPath != 0);
+
+    mConnName = QLatin1String(name);
+    mConnPath = QLatin1String(connPath);
+
+    g_free(name);
+    g_free(connPath);
+
+    mConn = Connection::create(mConnName, mConnPath);
+    QCOMPARE(mConn->isReady(), false);
+
+    mConn->requestConnect();
+
+    QVERIFY(connect(mConn->requestConnect(),
+                    SIGNAL(finished(Tp::PendingOperation*)),
+                    SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
+    QCOMPARE(mLoop->exec(), 0);
+    QCOMPARE(mConn->isReady(), true);
+    QCOMPARE(static_cast<uint>(mConn->status()),
+            static_cast<uint>(Connection::StatusConnected));
+
+    // create a Channel by magic, rather than doing D-Bus round-trips for it
+
+    mContactRepo = tp_base_connection_get_handles(mBaseConnService,
             TP_HANDLE_TYPE_CONTACT);
     guint handle = tp_handle_ensure(mContactRepo, "someone@localhost", 0, 0);
 
-    mContact = mConn->contacts(UIntList() << handle).first();
-    QVERIFY(mContact);
-
-    // create a Channel by magic, rather than doing D-Bus round-trips for it
-    mTextChanPath = mConn->objectPath() + QLatin1String("/TextChannel");
+    mTextChanPath = mConnPath + QLatin1String("/TextChannel");
     QByteArray chanPath(mTextChanPath.toAscii());
     mTextChanService = EXAMPLE_ECHO_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_CHANNEL,
-                "connection", mConn->service(),
+                "connection", mConnService,
                 "object-path", chanPath.data(),
                 "handle", handle,
                 NULL));
 
-    mMessagesChanPath = mConn->objectPath() + QLatin1String("/MessagesChannel");
+    mMessagesChanPath = mConnPath + QLatin1String("/MessagesChannel");
     chanPath = mMessagesChanPath.toAscii();
     mMessagesChanService = EXAMPLE_ECHO_2_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_2_CHANNEL,
-                "connection", mConn->service(),
+                "connection", mConnService,
                 "object-path", chanPath.data(),
                 "handle", handle,
                 NULL));
+
+    tp_handle_unref(mContactRepo, handle);
 }
 
 void TestTextChan::init()
@@ -168,8 +189,6 @@ void TestTextChan::init()
     initImpl();
 
     mChan.reset();
-    mGotChatStateChanged = false;
-    mChatStateChangedState = (ChannelChatState) -1;
 }
 
 void TestTextChan::commonTest(bool withMessages)
@@ -185,59 +204,6 @@ void TestTextChan::commonTest(bool withMessages)
     QVERIFY(asChannel->isReady());
     QVERIFY(mChan->isReady());
 
-    // hasChatStateInterface requires FeatureCore only
-    if (withMessages) {
-        QVERIFY(mChan->hasChatStateInterface());
-    } else {
-        QVERIFY(!mChan->hasChatStateInterface());
-    }
-
-    QVERIFY(!mChan->isReady(TextChannel::FeatureChatState));
-    QCOMPARE(mChan->chatState(mContact), ChannelChatStateInactive);
-    QCOMPARE(mChan->chatState(ContactPtr()), ChannelChatStateInactive);
-
-    QVERIFY(connect(asChannel->becomeReady(TextChannel::FeatureChatState),
-                SIGNAL(finished(Tp::PendingOperation *)),
-                SLOT(expectSuccessfulCall(Tp::PendingOperation *))));
-    QCOMPARE(mLoop->exec(), 0);
-    QVERIFY(mChan->isReady(TextChannel::FeatureChatState));
-
-    if (withMessages) {
-        QVERIFY(mChan->hasChatStateInterface());
-    } else {
-        QVERIFY(!mChan->hasChatStateInterface());
-    }
-
-    QCOMPARE(mChan->chatState(mContact), ChannelChatStateInactive);
-    QCOMPARE(mChan->chatState(ContactPtr()), ChannelChatStateInactive);
-    QCOMPARE(mChan->chatState(mChan->groupSelfContact()), ChannelChatStateInactive);
-
-    QVERIFY(connect(mChan.data(),
-                SIGNAL(chatStateChanged(Tp::ContactPtr,Tp::ChannelChatState)),
-                SLOT(onChatStateChanged(Tp::ContactPtr,Tp::ChannelChatState))));
-
-    if (withMessages) {
-        QVERIFY(connect(mChan->requestChatState(ChannelChatStateActive),
-                    SIGNAL(finished(Tp::PendingOperation *)),
-                    SLOT(expectSuccessfulCall(Tp::PendingOperation *))));
-        QCOMPARE(mLoop->exec(), 0);
-        while (!mGotChatStateChanged) {
-            mLoop->processEvents();
-        }
-        QCOMPARE(mChatStateChangedContact, mChan->groupSelfContact());
-        QCOMPARE(mChatStateChangedState, mChan->chatState(mChan->groupSelfContact()));
-        QCOMPARE(mChatStateChangedState, ChannelChatStateActive);
-    } else {
-        QVERIFY(connect(mChan->requestChatState(ChannelChatStateActive),
-                    SIGNAL(finished(Tp::PendingOperation *)),
-                    SLOT(expectFailure(Tp::PendingOperation *))));
-        QCOMPARE(mLoop->exec(), 0);
-        QCOMPARE(mLastError, TP_QT_ERROR_NOT_IMPLEMENTED);
-        QVERIFY(!mLastErrorMessage.isEmpty());
-    }
-
-    QVERIFY(!mChan->canInviteContacts());
-
     Features features = Features() << TextChannel::FeatureMessageQueue;
     QVERIFY(!mChan->isReady(features));
     // Implementation detail: in legacy text channels, capabilities arrive
@@ -264,12 +230,6 @@ void TestTextChan::commonTest(bool withMessages)
 
     sendText("One");
 
-    // Flush the D-Bus queue to make sure we've got the Sent signal the service will send, even if
-    // we are scheduled to execute between the time it calls return_from_send and emit_sent
-    processDBusQueue(mChan.data());
-
-    qDebug() << "making the Sent signal ready";
-
     // Make the Sent signal become ready
     features = Features() << TextChannel::FeatureMessageSentSignal;
     QVERIFY(connect(mChan->becomeReady(features),
@@ -284,14 +244,8 @@ void TestTextChan::commonTest(bool withMessages)
     features = Features() << TextChannel::FeatureMessageQueue;
     QVERIFY(!mChan->isReady(features));
 
-    qDebug() << "the Sent signal is ready";
-
     sendText("Two");
 
-    // Flush the D-Bus queue to make sure we've got the Sent signal the service will send, even if
-    // we are scheduled to execute between the time it calls return_from_send and emit_sent
-    processDBusQueue(mChan.data());
-
     // We should have received "Two", but not "One"
     QCOMPARE(sent.size(), 1);
     QCOMPARE(static_cast<uint>(sent.at(0).flags), 0U);
@@ -331,14 +285,7 @@ void TestTextChan::commonTest(bool withMessages)
         QCOMPARE(static_cast<uint>(mChan->messagePartSupport()),
                 static_cast<uint>(Tp::MessagePartSupportFlagOneAttachment |
                     Tp::MessagePartSupportFlagMultipleAttachments));
-        QCOMPARE(mChan->deliveryReportingSupport(), DeliveryReportingSupportFlagReceiveFailures);
-        QCOMPARE(mChan->supportedMessageTypes().size(), 3);
-        // Supports normal, action, notice
-        QVERIFY(mChan->supportsMessageType(Tp::ChannelTextMessageTypeNormal));
-        QVERIFY(mChan->supportsMessageType(Tp::ChannelTextMessageTypeAction));
-        QVERIFY(mChan->supportsMessageType(Tp::ChannelTextMessageTypeNotice));
-        QVERIFY(!mChan->supportsMessageType(Tp::ChannelTextMessageTypeAutoReply));
-        QVERIFY(!mChan->supportsMessageType(Tp::ChannelTextMessageTypeDeliveryReport));
+        QCOMPARE(static_cast<uint>(mChan->deliveryReportingSupport()), 0U);
     } else {
         QCOMPARE(mChan->supportedContentTypes(), QStringList() << QLatin1String("text/plain"));
         QCOMPARE(static_cast<uint>(mChan->messagePartSupport()), 0U);
@@ -367,21 +314,13 @@ void TestTextChan::commonTest(bool withMessages)
     QCOMPARE(mChan->messageQueue().size(), 2);
     QVERIFY(mChan->messageQueue().at(0) == received.at(0));
     QVERIFY(mChan->messageQueue().at(1) == received.at(1));
-    QVERIFY(received.at(0) != received.at(1));
 
     ReceivedMessage r(received.at(0));
-    QVERIFY(r == received.at(0));
     QCOMPARE(static_cast<uint>(r.messageType()),
             static_cast<uint>(Tp::ChannelTextMessageTypeNormal));
     QVERIFY(!r.isTruncated());
     QVERIFY(!r.hasNonTextContent());
-    if (withMessages) {
-        QCOMPARE(r.messageToken(), QLatin1String("0000"));
-        QCOMPARE(r.supersededToken(), QLatin1String("1234"));
-    } else {
-        QCOMPARE(r.messageToken(), QLatin1String(""));
-        QCOMPARE(r.supersededToken(), QString());
-    }
+    QCOMPARE(r.messageToken(), QLatin1String(""));
     QVERIFY(!r.isSpecificToDBusInterface());
     QCOMPARE(r.dbusInterface(), QLatin1String(""));
     QCOMPARE(r.size(), 2);
@@ -390,14 +329,8 @@ void TestTextChan::commonTest(bool withMessages)
     QCOMPARE(r.part(1).value(QLatin1String("content-type")).variant().toString(),
             QLatin1String("text/plain"));
     QCOMPARE(r.sender()->id(), QLatin1String("someone@localhost"));
-    QCOMPARE(r.senderNickname(), QLatin1String("someone@localhost"));
-    if (withMessages) {
-        QVERIFY(r.isScrollback());
-    } else {
-        QVERIFY(!r.isScrollback());
-    }
+    QVERIFY(!r.isScrollback());
     QVERIFY(!r.isRescued());
-    QVERIFY(!r.isDeliveryReport());
 
     // one "echo" implementation echoes the message literally, the other edits
     // it slightly
@@ -412,13 +345,7 @@ void TestTextChan::commonTest(bool withMessages)
             static_cast<uint>(Tp::ChannelTextMessageTypeNormal));
     QVERIFY(!r.isTruncated());
     QVERIFY(!r.hasNonTextContent());
-    if (withMessages) {
-        QCOMPARE(r.messageToken(), QLatin1String("0000"));
-        QCOMPARE(r.supersededToken(), QLatin1String("1234"));
-    } else {
-        QCOMPARE(r.messageToken(), QLatin1String(""));
-        QCOMPARE(r.supersededToken(), QString());
-    }
+    QCOMPARE(r.messageToken(), QLatin1String(""));
     QVERIFY(!r.isSpecificToDBusInterface());
     QCOMPARE(r.dbusInterface(), QLatin1String(""));
     QCOMPARE(r.size(), 2);
@@ -459,59 +386,12 @@ void TestTextChan::commonTest(bool withMessages)
     // per message, and fail one while succeeding with the other.
     mChan->acknowledge(mChan->messageQueue());
 
-    if (withMessages) {
-        sendText("Three (fail)");
-
-        // Flush the D-Bus queue to make sure we've got the Sent signal the service will send, even if
-        // we are scheduled to execute between the time it calls return_from_send and emit_sent
-        processDBusQueue(mChan.data());
-
-        // Assert that both our sent messages were echoed by the remote contact
-        while (received.size() != 3) {
-            QCOMPARE(mLoop->exec(), 0);
-        }
-        QCOMPARE(received.size(), 3);
-        QCOMPARE(mChan->messageQueue().size(), 1);
-        QVERIFY(mChan->messageQueue().at(0) == received.at(2));
-
-        r = received.at(2);
-        QVERIFY(r == received.at(2));
-        QCOMPARE(r.messageType(), Tp::ChannelTextMessageTypeDeliveryReport);
-        QVERIFY(!r.isTruncated());
-        QVERIFY(r.hasNonTextContent());
-        QCOMPARE(r.messageToken(), QLatin1String(""));
-        QVERIFY(!r.isSpecificToDBusInterface());
-        QCOMPARE(r.dbusInterface(), QLatin1String(""));
-        QCOMPARE(r.size(), 1);
-        QCOMPARE(r.header().value(QLatin1String("message-type")).variant().toUInt(),
-                static_cast<uint>(Tp::ChannelTextMessageTypeDeliveryReport));
-        QCOMPARE(r.sender()->id(), QLatin1String("someone@localhost"));
-        QCOMPARE(r.senderNickname(), QLatin1String("someone@localhost"));
-        QVERIFY(!r.isScrollback());
-        QVERIFY(!r.isRescued());
-        QCOMPARE(r.supersededToken(), QString());
-        QVERIFY(r.isDeliveryReport());
-        QVERIFY(r.deliveryDetails().isValid());
-        QVERIFY(r.deliveryDetails().hasOriginalToken());
-        QCOMPARE(r.deliveryDetails().originalToken(), QLatin1String("1111"));
-        QCOMPARE(r.deliveryDetails().status(), Tp::DeliveryStatusPermanentlyFailed);
-        QVERIFY(r.deliveryDetails().isError());
-        QCOMPARE(r.deliveryDetails().error(), Tp::ChannelTextSendErrorPermissionDenied);
-        QVERIFY(r.deliveryDetails().hasDebugMessage());
-        QCOMPARE(r.deliveryDetails().debugMessage(), QLatin1String("You asked for it"));
-        QCOMPARE(r.deliveryDetails().dbusError(), TP_QT_ERROR_PERMISSION_DENIED);
-        QVERIFY(r.deliveryDetails().hasEchoedMessage());
-        QCOMPARE(r.deliveryDetails().echoedMessage().text(), QLatin1String("Three (fail)"));
-
-        mChan->acknowledge(QList<ReceivedMessage>() << received.at(2));
-    }
-
     // wait for everything to settle down
     while (tp_text_mixin_has_pending_messages(
                 G_OBJECT(mTextChanService), 0)
             || tp_message_mixin_has_pending_messages(
                 G_OBJECT(mMessagesChanService), 0)) {
-        QTest::qWait(1);
+        QTest::qWait(100);
     }
 
     QVERIFY(!tp_text_mixin_has_pending_messages(
@@ -522,14 +402,14 @@ void TestTextChan::commonTest(bool withMessages)
 
 void TestTextChan::testMessages()
 {
-    mChan = TextChannel::create(mConn->client(), mMessagesChanPath, QVariantMap());
+    mChan = TextChannel::create(mConn, mMessagesChanPath, QVariantMap());
 
     commonTest(true);
 }
 
 void TestTextChan::testLegacyText()
 {
-    mChan = TextChannel::create(mConn->client(), mTextChanPath, QVariantMap());
+    mChan = TextChannel::create(mConn, mTextChanPath, QVariantMap());
 
     commonTest(false);
 }
@@ -545,8 +425,22 @@ void TestTextChan::cleanup()
 
 void TestTextChan::cleanupTestCase()
 {
-    QCOMPARE(mConn->disconnect(), true);
-    delete mConn;
+    if (mConn) {
+        // Disconnect and wait for the readiness change
+        QVERIFY(connect(mConn->requestDisconnect(),
+                        SIGNAL(finished(Tp::PendingOperation*)),
+                        SLOT(expectSuccessfulCall(Tp::PendingOperation*))));
+        QCOMPARE(mLoop->exec(), 0);
+
+        if (mConn->isValid()) {
+            QVERIFY(connect(mConn.data(),
+                            SIGNAL(invalidated(Tp::DBusProxy *,
+                                               const QString &, const QString &)),
+                            mLoop,
+                            SLOT(quit())));
+            QCOMPARE(mLoop->exec(), 0);
+        }
+    }
 
     if (mTextChanService != 0) {
         g_object_unref(mTextChanService);
@@ -558,6 +452,12 @@ void TestTextChan::cleanupTestCase()
         mMessagesChanService = 0;
     }
 
+    if (mConnService != 0) {
+        mBaseConnService = 0;
+        g_object_unref(mConnService);
+        mConnService = 0;
+    }
+
     cleanupTestCaseImpl();
 }
 
