@@ -136,7 +136,7 @@ example_contact_list_normalize_contact (TpHandleRepoIface *repo,
 {
   if (id[0] == '\0')
     {
-      g_set_error (error, TP_ERROR, TP_ERROR_INVALID_HANDLE,
+      g_set_error (error, TP_ERRORS, TP_ERROR_INVALID_HANDLE,
           "Contact ID must not be empty");
       return NULL;
     }
@@ -152,7 +152,7 @@ example_contact_list_normalize_group (TpHandleRepoIface *repo,
 {
   if (id[0] == '\0')
     {
-      g_set_error (error, TP_ERROR, TP_ERROR_INVALID_HANDLE,
+      g_set_error (error, TP_ERRORS, TP_ERROR_INVALID_HANDLE,
           "Contact group name cannot be empty");
       return NULL;
     }
