@@ -18,7 +18,6 @@
 #include <telepathy-glib/presence-mixin.h>
 
 #include "simple-conn.h"
-#include "contact-list-manager.h"
 
 G_BEGIN_DECLS
 
@@ -40,8 +39,6 @@ struct _TpTestsContactsConnection {
     TpPresenceMixin presence_mixin;
     TpContactsMixin contacts_mixin;
 
-    guint refresh_contact_info_called;
-
     TpTestsContactsConnectionPrivate *priv;
 };
 
@@ -74,9 +71,6 @@ typedef enum {
   (G_TYPE_INSTANCE_GET_CLASS ((obj), TP_TESTS_TYPE_CONTACTS_CONNECTION, \
                               TpTestsContactsConnectionClass))
 
-TestContactListManager *tp_tests_contacts_connection_get_contact_list_manager (
-    TpTestsContactsConnection *self);
-
 void tp_tests_contacts_connection_change_aliases (
     TpTestsContactsConnection *self, guint n,
     const TpHandle *handles, const gchar * const *aliases);
@@ -95,8 +89,7 @@ void tp_tests_contacts_connection_change_avatar_data (
     TpHandle handle,
     GArray *data,
     const gchar *mime_type,
-    const gchar *token,
-    gboolean emit_avatar_updated);
+    const gchar *token);
 
 void tp_tests_contacts_connection_change_locations (
     TpTestsContactsConnection *self,
@@ -114,10 +107,7 @@ void tp_tests_contacts_connection_set_default_contact_info (
     TpTestsContactsConnection *self,
     GPtrArray *info);
 
-void tp_tests_contacts_connection_change_client_types (
-    TpTestsContactsConnection *self, TpHandle handle, gchar **client_types);
-
-/* Legacy version (no Contacts interface, and no immortal handles) */
+/* Legacy version (no Contacts interface) */
 
 typedef struct _TpTestsLegacyContactsConnection TpTestsLegacyContactsConnection;
 typedef struct _TpTestsLegacyContactsConnectionClass TpTestsLegacyContactsConnectionClass;
